<?php

/*----------------------------------------------------------------------------------------------------------
    MODULE 4 Frivstyle - DISPLAYS RECENT POSTS
-----------------------------------------------------------------------------------------------------------*/


class Jumbo_Module_4 {

    function __construct() {

        $this->module_id = 4;

        add_action( 'vc_before_init', array( $this, 'jumbo_vc_map_module4' ) );
        add_shortcode( 'td_module4', array( $this, 'render' ) );
    }


/*----------------------------------------------------
    RENDER SHORTCODE FUNCTION
-----------------------------------------------------*/

    function render( $atts ) {

        extract( shortcode_atts(
            array(
                'custom_title'  => '',
                'sub_title'     => '',
                'custom_url'    => '',
                'fa_icon'       => '',
                'color'         => '',
                'category_id'   => '',
                'order_post'    => '',
                'tag_slug'      => '',
                'post_limit'    => 4
                ), $atts) );


        $td_return_module4_image_small = '<div class="td-noimage-fit-4"></div>';
        $td_image_size_small = 'jumbo-module-2-small';

        $buffer = '';

        $td_args = array(
            'ignore_sticky_posts' => 1
            );

        if ( !empty( $category_id ) and $category_id != 'All Categories' ) {
            $td_args['category_name'] = $category_id;
        }

        if (!empty($tag_slug)) {
            $td_args['tag'] = str_replace(' ', '-', $tag_slug);
        }

        switch ( $order_post ) {

            case 'random_posts':
            $td_args['orderby'] = 'rand';
            break;

            case 'alphabetical_order':
            $td_args['orderby'] = 'title';
            $td_args['order'] = 'ASC';
            break;

            case 'comment_count':
            $td_args['orderby'] = 'comment_count';
            $td_args['order'] = 'DESC';
            break;

            case 'views_count':
            $td_args['orderby'] = 'meta_value_num';
            $td_args['meta_key'] = 'post_views_count';
            break;

            case 'trending':
            $td_args['orderby'] = 'meta_value_num';
            $td_args['meta_key'] = 'post_views_count';
            $td_args['date_query'] = array(
                'column' => 'post_date_gmt',
                'after' => '1 week ago'
                );
            break;

            case 'popular_7_days':
            $td_args['orderby'] = 'comment_count';
            $td_args['date_query'] = array(
                'column' => 'post_date_gmt',
                'after' => '1 week ago'
                );
            break;

            }

            $td_args['post_status'] = 'publish';
            $td_args['posts_per_page'] = $post_limit;

             if ( empty( $custom_title ) ) {
                $td_module_title4 = $category_id;
            } else {
                $td_module_title4 = htmlspecialchars( $custom_title, ENT_QUOTES );
            }

            // module url by selected category
            $td_category_id = get_cat_ID( $category_id );
            $td_module_url4 = get_category_link( $td_category_id );

            // module title
        if ( !empty( $color) ) {
            $border_color = 'style="border-bottom: 2px solid ' . esc_attr( $color ). ';"';
        } else {
            $border_color = '';
        }
        $buffer .= '<div class="td-module-title widget-title" '.  wp_kses_post( $border_color ) .' >';
        $buffer .= '<h3 style="background-color:' . esc_attr( $color ). ';">';

        if ( $fa_icon ) {
            $buffer .= '<span class="td-mod-fa"><i class="fa '. esc_attr( $fa_icon ). '"></i></span>';
        }


            // if custom URL is set by the user, link the module title with it
            if ( !empty( $custom_url ) ) {
                $buffer .= '<a style="background-color:' . esc_attr( $color ). '"; href="' . esc_url( $custom_url ). '" title="' . esc_html( $td_module_title4 ). '">';
                $buffer .= $td_module_title4;
                $buffer .= '</a>';
            // else if custom URL is not set by the user and is selected a certain category, link the module title with the selected category link
            } elseif ( empty( $custom_url ) and !empty( $category_id ) and $category_id != 'All Categories' ) {
                $buffer .= $td_module_title4;
            // if custom URL is not set by the user and is selected "All Categories" the module title will not have an URL
            } else {
                $buffer .= $td_module_title4;
            }

            $buffer .= '</h3>';

            // optional subtitle
            if ( !empty( $sub_title ) ) {
            $buffer .= '<div class="td-subtitle">';
            $buffer .= htmlspecialchars( $sub_title, ENT_QUOTES );
            $buffer .= '</div>';
        }
            $buffer .= '</div>';


        // display posts
        $td_query = new WP_Query( $td_args );

        if ( $td_query->have_posts() ) {

            while ( $td_query->have_posts() ) {
                $td_query->the_post();

                // check if post has thumbnail
                if ( '' != get_the_post_thumbnail() )  {

                   $module4_small_images = '<a class="module-image" href="' . get_permalink() . '">' . get_the_post_thumbnail( get_the_ID(), $td_image_size_small ) . '</a>';
               } else {
                // display placeholder module
                $module4_small_images = '<a class="module-image" href="' . get_permalink() . '">' . $td_return_module4_image_small . '</a>';
            }

            $buffer .= '<div class="td-fly-in td-friv grid-image grid col-146">';
            $buffer .= '<div title="' . get_the_title() . '">';
            $buffer .= $module4_small_images;
            $buffer .= '</div>';
            $buffer .= '</div>';

        }

    }

    wp_reset_postdata();

    return '<div class="td-module-4-wrap">' . balanceTags( $buffer ). '</div>';

} // End of render shortcode function


/*----------------------------------------------------
    VISUAL COMPOSER MAPPING PARAMETERS
-----------------------------------------------------*/

function jumbo_vc_map_module4() {

         vc_map( array(
            'name'      => esc_html__( 'Frivstyle', 'jumbo' ),
            'base'      => 'td_module4',
            'class'     => 'td_module4',
            'category'  => esc_html__( 'Jumbo Modules', 'jumbo' ),
            'icon'      => 'icon-module4',
            'params' => array(
                array(
                'param_name'    => 'category_id',
                'type'          => 'dropdown',
                'value'         => Jumbo_Core::jumbo_get_module_categories(),
                'heading'       => esc_html__( 'Category filter:', 'jumbo' ),
                'description'   => '',
                'holder'        => 'div',
                'class'         => ''
                ),
             array(
                'param_name'    => 'custom_title',
                'type'          => 'textfield',
                'value'         => '',
                'heading'       => esc_html__( 'Custom title for this module:', 'jumbo' ),
                'description'   => 'Leave it blank to display category title for this module, if you have selected one above.',
                'holder'        => 'div',
                'class'         => ''
                ),
             array(
                'param_name'    => 'sub_title',
                'type'          => 'textfield',
                'value'         => '',
                'heading'       => esc_html__( 'Optional subtitle for this module:', 'jumbo' ),
                'description'   => '',
                'holder'        => 'div',
                'class'         => ''
                ),
             array(
                'param_name'    => 'fa_icon',
                'type'          => 'textfield',
                'value'         => '',
                'heading'       => esc_html__( 'Optional Font Awesome icon:', 'jumbo' ),
                'description'   => 'Example: fa-car',
                'holder'        => 'div',
                'class'         => ''
                ),
             array(
                "type" => "colorpicker",
                "class" => "",
                "heading" => esc_html__( 'Background color for this module title', 'jumbo' ),
                "param_name" => "color",
                "value" => '',
                "description" => ''
             ),
             array(
                'param_name'    => 'custom_url',
                'type'          => 'textfield',
                'value'         => '',
                'heading'       => esc_html__( 'Custom url for module title:', 'jumbo' ),
                'description'   => 'Leave it blank to display category url for this module, if you have selected one above.',
                'holder'        => 'div',
                'class'         => ''
                ),
             array(
                'param_name'    => 'order_post',
                'type'          => 'dropdown',
                'value'         => array( '- Latest -' => '', 'Alphabetical' => 'alphabetical_order', 'Random Posts' => 'random_posts', 'Trending' => 'trending', 'Popular Posts Last Week' => 'popular_7_days', 'Most Commented' => 'comment_count', 'Most Viewed' => 'views_count' ),
                'heading'       => esc_html__( 'Sort order:', 'jumbo' ),
                'description'   => 'Note that selecting "Trending" or "Popular Posts Last Week" will only return posts published over a week ago. Therefore, if you have not published any posts in the last week, the module will not display any post.',
                'holder'        => 'div',
                'class'         => ''
                ),
              array(
                'param_name'    => 'tag_slug',
                'type'          => 'textfield',
                'value'         => '',
                'heading'       => esc_html__( 'Filter by tag slug:', 'jumbo' ),
                'description'   => 'This module will display only one post that has the tag slug that you enter here. To filter by multiple tag slugs, enter here the tag slugs separated by commas (example: movie,fun,apps)',
                'holder'        => 'div',
                'class'         => ''
                ),
             array(
                'param_name'    => 'post_limit',
                'type'          => 'textfield',
                'value'         => 4,
                'heading'       => esc_html__( 'Number of posts to show:', 'jumbo' ),
                'description'   => 'Type only even numbers.',
                'holder'        => 'div',
                'class'         => ''
                )
             )
    ) );

} // End of function jumbo_vc_map_module4


} // End of class Jumbo_Module_4

$td_module4 = new Jumbo_Module_4();