<?php
/**
 * SMOF Admin
 *
 * @package     WordPress
 * @subpackage  SMOF
 * @since       1.4.0
 * @author      Syamil MJ
 */


/**
 * Head Hook
 *
 * @since 1.0.0
 */
function of_head() { do_action( 'of_head' ); }

/**
 * Add default options upon activation else DB does not exist
 *
 * DEPRECATED, Class_options_machine now does this on load to ensure all values are set
 *
 * @since 1.0.0
 */
function of_option_setup()
{
	global $of_options, $options_machine;
	$options_machine = new Jumbo_Options_Machine($of_options);

	if (!of_get_options())
	{
		of_save_options($options_machine->Defaults);
	}
}


/*----------------------------------------------------------------------------------------------------------
	Customize theme activation message and add useful button links
-----------------------------------------------------------------------------------------------------------*/

	function optionsframework_activation_notice() {

		if ( isset( $_GET['activated'] ) ) {

			$output = '<div class="updated activation notice is-dismissible"><p><strong>';
			$my_theme = wp_get_theme();
			$output .= sprintf( esc_html__( '%s activated successfully!', 'jumbo' ), $my_theme->get( 'Name' ) );
			$output .= '</strong> <a target="_blank" href="' . esc_url( home_url( '/' ) ) . '">' . esc_html__( 'Visit Site', 'jumbo' ) . '</a></p>';
			$output .= ' <a class="button button-primary td-activation" href="' . admin_url( 'themes.php?page=jumbo_panel' ) . '">' . esc_html__( 'Theme Options', 'jumbo' ) . '</a>';
			$output .= ' <a class="button button-primary td-activation" href="' . admin_url( 'widgets.php' ) . '">' . esc_html__( 'Widgets Settings', 'jumbo' ) . '</a>';
			$output .= ' <a class="button button-primary td-activation" target="_blank" href="http://tiguandesign.ticksy.com/">' . esc_html__( 'Support', 'jumbo' ) . '</a>';
			$output .= ' <a class="button button-primary td-activation" target="_blank" href="http://tiguandesign.com/docs/jumbo">' . esc_html__( 'Documentation', 'jumbo' ) . '</a>';
			$output .= '</p></div>';

			echo wp_kses_post( $output );

		}	//END if

	}	//	END function optionsframework_activation_notice


/*----------------------------------------------------------------------------------------------------------
	Hide core theme activation message and change some css
-----------------------------------------------------------------------------------------------------------*/

	function optionsframework_hide_activation() { ?>
	<style>
	.themes-php #message2 {
		display: none;
	}
	.themes-php div.activation a {
		text-decoration: none;
	}
	.button-primary.td-activation {
		border-radius: 0;
	}
	</style>
	<?php }



/**
 * Get header classes
 *
 * @since 1.0.0
 */
function of_get_header_classes_array()
{
	global $of_options;

	foreach ($of_options as $value)
	{
		if ($value['type'] == 'heading')
			$hooks[] = str_replace(' ','',strtolower($value['name']));
	}

	return $hooks;
}

/**
 * Get options from the database and process them with the load filter hook.
 *
 * @author Jonah Dahlquist
 * @since 1.4.0
 * @return array
 */
function of_get_options($key = null, $data = null) {
	global $tiguan_data;

	do_action('of_get_options_before', array(
		'key'=>$key, 'data'=>$data
	));
	if ($key != null) { // Get one specific value
		$data = get_theme_mod($key, $data);
	} else { // Get all values
		$data = get_theme_mods();
	}
	$data = apply_filters('of_options_after_load', $data);
	if ($key == null) {
		$tiguan_data = $data;
	} else {
		$tiguan_data[$key] = $data;
	}
	do_action('of_option_setup_before', array(
		'key'=>$key, 'data'=>$data
	));
	return $data;

}

/**
 * Save options to the database after processing them
 *
 * @param $data Options array to save
 * @author Jonah Dahlquist
 * @since 1.4.0
 * @uses update_option()
 * @return void
 */

function of_save_options($data, $key = null) {
	global $tiguan_data;
    if (empty($data))
        return;
    do_action('of_save_options_before', array(
		'key'=>$key, 'data'=>$data
	));
	$data = apply_filters('of_options_before_save', $data);
	if ($key != null) { // Update one specific value
		if ($key == BACKUPS) {
			unset($data['smof_init']); // Don't want to change this.
		}
		set_theme_mod($key, $data);
	} else { // Update all values in $data
		foreach ( $data as $k=>$v ) {
			if (!isset($tiguan_data[$k]) || $tiguan_data[$k] != $v) { // Only write to the DB when we need to
				set_theme_mod($k, $v);
			} else if (is_array($v)) {
				foreach ($v as $key=>$val) {
					if ($key != $k && $v[$key] == $val) {
						set_theme_mod($k, $v);
						break;
					}
				}
			}
	  	}
	}
    do_action('of_save_options_after', array(
		'key'=>$key, 'data'=>$data
	));

}


/**
 * For use in themes
 *
 * @since forever
 */

$data = of_get_options();
if (!isset($tiguan_details))
	$tiguan_details = array();