<?php

// If this file is called directly, busted!
if( !defined( 'ABSPATH' ) ) {
	exit;
}

/*----------------------------------------------------------------------------------------------------------
	MAIN THEME'S FUNCTIONS AND DEFINITIONS
-----------------------------------------------------------------------------------------------------------*/
?>
<?php

/* Define a global theme constant to be used by our plugins to handle some actions */
define( 'JUMBO_THEME_WP_HOOK', false );

/* Define a global theme version  to handle some demo hooks. */
define( 'JUMBO_THEME_VERSION', '1.0' );

/* Define a global theme constant to handle some demo hooks. Uses 'demo' or 'default'. */
define( 'JUMBO_THEME_DEMO_MODE', 'demo' );

/* Add TGM plugin Updater */
require_once( get_template_directory() . '/inc/includes/classes/class-tgm-plugin-activation.php');

/* Add SMOF class to avoid using globals */
require_once( get_template_directory() . '/inc/includes/classes/jumbo-class-data.php');

/* Add post-formats */
add_theme_support('post-formats', array( 'image', 'video' ));



/*----------------------------------------------------------------------------------------------------------
 * Allows file locations in child themes.
 * If the file is not being overwritten by the child theme then return the parent theme location of the file.
-----------------------------------------------------------------------------------------------------------*/

function jumbo_child_uri( $dir ) {
	if( is_child_theme() ) {
		$directory = get_stylesheet_directory() . $dir;
		$test = is_file( $directory );
		if( is_file( $directory ) ) {
			$file = get_stylesheet_directory_uri() . $dir;
		} else {
			$file = get_template_directory_uri() . $dir;
		}
	} else {
		$file = get_template_directory_uri() . $dir;
	}

	return $file;
}


/*----------------------------------------------------------------------------------------------------------
	Return values from the theme options using 'jumbo_get_option'
-----------------------------------------------------------------------------------------------------------*/

function jumbo_get_option( $option, $default = false ) {

	global $tiguan_data;

	if( isset( $tiguan_data[$option] ) ) {
		return $tiguan_data[$option];
	}

	return $default;
}

/*----------------------------------------------------------------------------------------------------------
	Global $wp_query within a funtion
-----------------------------------------------------------------------------------------------------------*/

function jumbo_wp_query_var() {
	global $wp_query;
	return $wp_query;
}

/*----------------------------------------------------------------------------------------------------------
	Global $paged within a funtion
-----------------------------------------------------------------------------------------------------------*/

function jumbo_paged_var() {
	global $paged;
	return $paged;
}

/*----------------------------------------------------------------------------------------------------------
	Global $post within a funtion
-----------------------------------------------------------------------------------------------------------*/

function jumbo_post_var() {
	global $post;
	return $post;
}

/*----------------------------------------------------------------------------------------------------------
	Return dynamic style css
-----------------------------------------------------------------------------------------------------------*/

function jumbo_echo_css( $css ) {
	return $css;
}


/*----------------------------------------------------------------------------------------------------------
	JUMBO THEME SETUP
-----------------------------------------------------------------------------------------------------------*/

if( !function_exists( 'jumbo_setup' ) ) {

	function jumbo_setup() {

		global $content_width;

		// global content width.
		if( !isset( $content_width ) ) {
			$content_width = 728;
		}

		// Load theme textdomain.
		load_theme_textdomain( 'jumbo', WP_LANG_DIR . '/jumbo/' );
		load_theme_textdomain( 'jumbo', get_stylesheet_directory() . '/languages/' );
		load_theme_textdomain( 'jumbo', get_template_directory() . '/languages/' );

		// Add callback for custom TinyMCE editor stylesheets. (editor-style.css)
		add_editor_style();

		// Enable post and comment RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		// Enable post-thumbnail support.
		add_theme_support( 'post-thumbnails' );

		//  Add theme support for title tag (since wp 4.1)
		add_theme_support( 'title-tag' );

		// Theme-Check Tweak
		add_theme_support( 'custom-background' );
		add_theme_support( 'custom-header' );
		remove_theme_support( 'custom-background' );
		remove_theme_support( 'custom-header' );

		// Set post featured image size
		$td_crop_features_image	= jumbo_get_option( 'td_crop_featured_image' );

		if ( $td_crop_features_image == 1 ) { // featured image on post
			add_image_size( 'jumbo-featured-image', 728, 350, true );
		    add_image_size( 'jumbo-full-featured', 1116, 480, true );
		} else {
		    add_image_size( 'jumbo-featured-image', 728, 0, true );
		    add_image_size( 'jumbo-full-featured', 1116, 0, true );
		}

		add_image_size( 'jumbo-module-3', 340, 215, true );				// image size for module 1
		add_image_size( 'jumbo-module-10', 340, 352, true ); 				// image size for module 10 - big image
		add_image_size( 'jumbo-module-12', 340, 454, true ); 				// image size for module 12 - big image
		add_image_size( 'jumbo-module-2-small', 104, 104, true ); 		// image size for module 2 - small images
		add_image_size( 'jumbo-modular-slider', 658, 401, true ); 		// image size for modular slider
		add_image_size( 'jumbo-modular-slider-small', 228, 200, true );   // image size for modular-slider-small
		add_image_size( 'jumbo-big-first-image', 728, 384, true );		// image size for Top Big Picture module
		add_image_size( 'jumbo-annete-module', 1116, 280, true );		    // image size for Annete module

		// Set post thumbnail size
		if( !is_admin() ) {
		set_post_thumbnail_size( 104, 104, true );
	}


		// Enables custom-menus support.
		register_nav_menus( array(
			'top-menu'        	=> esc_html__( 'Top Menu', 'jumbo' ),
			'main-menu'       	=> esc_html__( 'Header Menu', 'jumbo' ),
			'footer-menu'     	=> esc_html__( 'Footer Menu', 'jumbo' )
			)
		);
	}

}

add_action( 'after_setup_theme', 'jumbo_setup' );



/*----------------------------------------------------------------------------------------------------------
	Custom translation function
-----------------------------------------------------------------------------------------------------------*/

if ( !function_exists( '__jumbo_translate' ) ) {

	function __jumbo_translate( $string_value ) { // get theme translated string

		if ( ( $translated_string = jumbo_get_option( 'td_'.$string_value ) ) && jumbo_get_option( 'td_enable_translator' ) ) {

			return esc_attr( $translated_string ); // read the user translations

		} else {

			$translate = jumbo_get_translate_options();
			return $translate[$string_value]['translated_words']; // return the default translation or read it from .mo file
		}
	}

}


/*----------------------------------------------------------------------------------------------------------
	Get all theme translation strings
-----------------------------------------------------------------------------------------------------------*/

if ( !function_exists( 'jumbo_get_translate_options' ) ) {

	function jumbo_get_translate_options() {
		include( get_template_directory() . '/inc/includes/translate.php');
		$translate = apply_filters( 'jumbo_modify_translate_options', $td_translate );
		return $translate;
	}

}


/*----------------------------------------------------------------------------------------------------------
	Check whether the plugin is active and theme can rely on it
-----------------------------------------------------------------------------------------------------------*/

function jumbo_can_use_plugin( $plugin ) {
	// Detect plugin. For use on Front End only.
	include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

	return is_plugin_active( $plugin );
}


/*----------------------------------------------------------------------------------------------------------
  Add meta entry likes to single post, archive and blog list if set in theme options.
-----------------------------------------------------------------------------------------------------------*/

if( !function_exists( 'jumbo_likes' ) ) {

  function jumbo_likes() {

    if ( jumbo_can_use_plugin( 'i-recommend-this/dot-irecommendthis.php' ) ) {
    	echo '<span class="post-likes-count">';
    	dot_irecommendthis( );
    	echo '</span>';
    }

  }

}


/*----------------------------------------------------------------------------------------------------------
	Single Meta Color
-----------------------------------------------------------------------------------------------------------*/

if ( !function_exists( 'jumbo_single_meta_color' ) ) {

	function jumbo_single_meta_color() {

		echo '<div class="td-image-meta-box">';

if ( comments_open() ) {

		echo '<div class="td-comments-count-color-box">';
		$num_comments = get_comments_number(); // get_comments_number returns only a numeric value

		$td_comments_color = '<i class="fa fa-commenting"></i>';


			if ( $num_comments == 0 ) {
				$comments = $num_comments;
			} elseif ( $num_comments > 1 ) {
				$comments = $num_comments ;
			} else {
				$comments = '1';
			}


		echo wp_kses_post( $td_comments_color );
		echo wp_kses_post ( $comments );
		echo '</div>';
}
		echo '<div class="td-views-counter">' ;
		echo jumbo_post_views();
		echo '</div>';

		if ( jumbo_can_use_plugin( 'i-recommend-this/dot-irecommendthis.php' ) ) {
			echo '<div class="td-post-like">';
			echo jumbo_likes();
			echo '</div>';
		}
		echo '</div>';
	}
}


/*----------------------------------------------------------------------------------------------------------
        Get the title function
-----------------------------------------------------------------------------------------------------------*/

if( !function_exists( 'jumbo_get_post_title' ) ) {

    function jumbo_get_post_title() {

        global $post;
        $td_the_title = get_the_title();
        $td_title_attribute = esc_attr( strip_tags( $td_the_title ) );
        $td_href = get_permalink( $post->ID );

        $buffer = '';
        $buffer .= '<h3 class="entry-title">';
        $buffer .= '<a href="' . esc_url( $td_href ) . '" rel="bookmark" title="' . esc_html( $td_title_attribute ) . '">';
        $buffer .= $td_the_title;
        $buffer .= '</a>';
        $buffer .= '</h3>';

        return $buffer;
    }
}


/*----------------------------------------------------------------------------------------------------------
	Set a fallback menu that will show a home link.
-----------------------------------------------------------------------------------------------------------*/

function jumbo_fallback_menu() {
	$args    = array(
		'depth'       => 0,
		'sort_column' => 'menu_order, post_title',
		'menu_class'  => 'menu',
		'include'     => '',
		'exclude'     => '',
		'echo'        => false,
		'show_home'   => true,
		'link_before' => '',
		'link_after'  => ''
		);
	$pages   = wp_page_menu( $args );
	$prepend = '<div class="main-nav">';
	$append  = '</div>';
	$buffer  = $prepend . $pages . $append;
	echo wp_kses_post( $buffer );
}


/*
 * These functions removes .menu class from custom menus in widgets only and fallback's on default widget lists
 * and assigns new unique class called .menu-widget
 * Marko Heijnen Contribution
 */

class Jumbo_Widget_Menu_Class {
	public function __construct() {
		add_action( 'widget_display_callback', array( $this, 'menu_different_class' ), 10, 2 );
	}

	public function menu_different_class( $settings, $widget ) {
		if( $widget instanceof WP_Nav_Menu_Widget ) {
			add_filter( 'wp_nav_menu_args', array( $this, 'wp_nav_menu_args' ) );
		}

		return $settings;
	}

	public function wp_nav_menu_args( $args ) {
		remove_filter( 'wp_nav_menu_args', array( $this, 'wp_nav_menu_args' ) );

		if( 'menu' == $args['menu_class'] ) {
			$args['menu_class'] = apply_filters( 'jumbo_widget_menu_class', 'menu-widget' );
		}

		return $args;
	}
}

$GLOBALS['nav_menu_widget_classname'] = new Jumbo_Widget_Menu_Class();


/*----------------------------------------------------------------------------------------------------------
	Removes div from wp_page_menu() and replace with ul.
-----------------------------------------------------------------------------------------------------------*/

function jumbo_wp_page_menu( $page_markup ) {
	preg_match( '/^<div class=\"([a-z0-9-_]+)\">/i', $page_markup, $matches );
	$divclass   = $matches[1];
	$replace    = array( '<div class="' . esc_attr( $divclass ) . '">', '</div>' );
	$new_markup = str_replace( $replace, '', $page_markup );
	$new_markup = preg_replace( '/^<ul>/i', '<ul class="' . esc_attr( $divclass ) . '">', $new_markup );

	return $new_markup;
}

add_filter( 'wp_page_menu', 'jumbo_wp_page_menu' );


/*----------------------------------------------------------------------------------------------------------
	Filter 'get_comments_number' to display correct number of comments - Chip Bennett Contribution
-----------------------------------------------------------------------------------------------------------*/

function jumbo_comment_count( $count ) {
	if( !is_admin() ) {
		global $id;
		$comments         = get_comments( 'status=approve&post_id=' . $id );
		$comments_by_type = separate_comments( $comments );

		return count( $comments_by_type['comment'] );

	} else {

		return $count;
	}
}

add_filter( 'get_comments_number', 'jumbo_comment_count', 0 );


/*----------------------------------------------------------------------------------------------------------
	wp_list_comments() Callback function for Pings (Trackbacks/Pingbacks)
-----------------------------------------------------------------------------------------------------------*/

function jumbo_comment_list_pings( $comment ) {
	$GLOBALS['comment'] = $comment;
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>"><?php echo comment_author_link(); ?></li>
	<?php
}


/*----------------------------------------------------------------------------------------------------------
	Add span wrap for archive count numbers in #widgets and remove their brackets
-----------------------------------------------------------------------------------------------------------*/

function jumbo_archive_number_span( $archivelinks ) {
	$archivelinks = str_replace('</a>&nbsp;(', '<span class="td-widget-extra">', $archivelinks);
		$archivelinks = str_replace(')', '</span></a>', $archivelinks);
		return $archivelinks;
	}

	add_filter('get_archives_link', 'jumbo_archive_number_span');


/*----------------------------------------------------------------------------------------------------------
	Add span wrap for category count numbers in #widgets and remove their brackets
-----------------------------------------------------------------------------------------------------------*/

function jumbo_cat_number_span( $catlinks ) {
	$catlinks = str_replace('</a> (', '<span class="td-widget-extra">', $catlinks);
		$catlinks = str_replace(')', '</span></a>', $catlinks);
		return $catlinks;
	}

	add_filter('wp_list_categories', 'jumbo_cat_number_span');


/*----------------------------------------------------------------------------------------------------------
	Sets the post excerpt length from theme options.
-----------------------------------------------------------------------------------------------------------*/

function jumbo_global_excerpt( $limit ) {
      return wp_trim_words( get_the_excerpt(), $limit );
    }

/*----------------------------------------------------------------------------------------------------------
  CUSTOM EXCERPT FOR BLOG LAYOUT
-----------------------------------------------------------------------------------------------------------*/

function jumbo_blog_excerpt_length( $length ) {
  $td_limit = jumbo_get_option( 'td_blog_style_excerpts_length' );
  return $td_limit;
}

add_filter( 'excerpt_length', 'jumbo_blog_excerpt_length', 999 );


/*----------------------------------------------------------------------------------------------------------
	Return a "Read more" link for excerpts
-----------------------------------------------------------------------------------------------------------*/

function jumbo_read_more( $more ) {

	global $post;

	$td_excerpts_text = JUMBO_Data::get( 'td_excerpts_text' );
	// get the excerpt more text from theme options.
	$text = $td_excerpts_text ;
	$text = $text == '' ? __jumbo_translate( 'read_more' ) : $text;

	$more = '&hellip;<p class="excerpt-more"><a class="excerpt-more button blog-excerpt" href="' . get_permalink( $post->ID ) . ' ">' . esc_html( $text ) . '</a></p>';

	return $more;
}

add_filter( 'excerpt_more', 'jumbo_read_more' );



/*----------------------------------------------------------------------------------------------------------
	This function displays the first category link/name of a post
-----------------------------------------------------------------------------------------------------------*/

if ( !function_exists( 'jumbo_single_cat' ) ) {

	function jumbo_single_cat() {
		$category = get_the_category();
		if ( $category ) {
			$module_category = '<a href="' . esc_url( get_category_link( $category[0]->term_id ) ) . '"' . '>' . esc_attr( $category[0]->name ).'</a> ';
		}

		return $module_category;

	}
}


/*----------------------------------------------------------------------------------------------------------
	This function prints post meta data.
-----------------------------------------------------------------------------------------------------------*/

if( !function_exists( 'jumbo_post_meta_data' ) ) {

	function jumbo_post_meta_data() {
		printf( __jumbo_translate( 'posted_on' ),
			'meta-prep meta-prep-author posted',
			sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><span class="timestamp updated">%3$s</span></a>',
				esc_url( get_permalink() ),
				esc_attr( get_the_time() ),
				esc_html( get_the_date() )
				),
			'byline',
			sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s">%3$s</a></span>',
				get_author_posts_url( get_the_author_meta( 'ID' ) ),
				sprintf( __jumbo_translate( 'view_all_posts_by' ), get_the_author() ),
				esc_attr( get_the_author() )
				)
			);
	}

}


/*----------------------------------------------------------------------------------------------------------
	Remove unwanted widgets from plugins
-----------------------------------------------------------------------------------------------------------*/

function jumbo_remove_widget() {
	unregister_widget( 'simple_ajax_auth' );
}

if ( jumbo_can_use_plugin( 'simple-ajax-auth/plugin.php' ) ) {
	add_action( 'widgets_init', 'jumbo_remove_widget' );
}


/*----------------------------------------------------------------------------------------------------------
	 Add Google Fonts to the generated page - credits: Kailoon: https://gist.github.com/kailoon
-----------------------------------------------------------------------------------------------------------*/
function jumbo_fonts_url() {

	$td_body_font 			= jumbo_get_option( 'td_body_font_family' );
	$td_widgets_font 		= jumbo_get_option( 'td_widgets_font_family' );
	$td_postpage_font 		= jumbo_get_option( 'td_postpage_font_family' );
	$td_topmenu_font 		= jumbo_get_option( 'td_top_menu_font_family' );
	$td_mainmenu_font 		= jumbo_get_option( 'td_main_menu_font_family' );
	$td_submenu_font 		= jumbo_get_option( 'td_sub_menu_font_family' );

// Google font subset
	$td_font_subset = JUMBO_Data::get( 'td_font_subset' );
	if ( empty( $td_font_subset ) ) {
		$td_subset = 'subset=latin';
	} else {
		$td_subset = 'subset='.$td_font_subset;
	}

    $font_url = '';


	// Body font
	if ( $td_body_font != '' and $td_body_font != 'none' and $td_body_font != 'Arial, Helvetica, sans-serif' and $td_body_font != 'Georgia, serif' and $td_body_font != 'Tahoma, Geneva, sans-serif' and $td_body_font != 'Verdana, Geneva, sans-serif' ) {
		$td_body_font_name = '|'.$td_body_font;

	} else {
		$td_body_font_name = '';

	}

	// Widgets title font
	if ( $td_body_font != $td_widgets_font and $td_widgets_font != '' and $td_widgets_font != 'none' and $td_widgets_font != 'Arial, Helvetica, sans-serif' and $td_widgets_font != 'Georgia, serif' and $td_body_font != 'Tahoma, Geneva, sans-serif' and $td_widgets_font != 'Verdana, Geneva, sans-serif' ) {
		$td_widgets_font_name = '|'.$td_widgets_font;

	} else {
		$td_widgets_font_name = '';

	}

	// Post and Page title font
	if ( $td_postpage_font != '' and $td_postpage_font != 'none' and $td_postpage_font != 'Arial, Helvetica, sans-serif' and $td_postpage_font != 'Georgia, serif' and $td_postpage_font != 'Tahoma, Geneva, sans-serif' and $td_postpage_font != 'Verdana, Geneva, sans-serif' ) {
		$td_postpage_font_name = '|'.$td_postpage_font;

	} else {
		$td_postpage_font_name = '';

	}

	// Top Menu font
	if ( $td_topmenu_font != '' and $td_topmenu_font != 'none' and $td_topmenu_font != 'Arial, Helvetica, sans-serif' and $td_topmenu_font != 'Georgia, serif' and $td_topmenu_font != 'Tahoma, Geneva, sans-serif' and $td_topmenu_font != 'Verdana, Geneva, sans-serif' ) {
		$td_topmenu_font_name = '|'.$td_topmenu_font;

	} else {
		$td_topmenu_font_name = '';

	}

	// Main Menu font
	if ( $td_mainmenu_font != '' and $td_mainmenu_font != 'none' and $td_mainmenu_font != 'Arial, Helvetica, sans-serif' and $td_mainmenu_font != 'Georgia, serif' and $td_mainmenu_font != 'Tahoma, Geneva, sans-serif' and $td_mainmenu_font != 'Verdana, Geneva, sans-serif' ) {
		$td_mainmenu_font_name = '|'.$td_mainmenu_font;

	} else {
		$td_mainmenu_font_name = '';

	}

	// Sub-Menu font
	if ( $td_submenu_font != '' and $td_submenu_font != 'none' and $td_submenu_font != 'Arial, Helvetica, sans-serif' and $td_submenu_font != 'Georgia, serif' and $td_submenu_font != 'Tahoma, Geneva, sans-serif' and $td_submenu_font != 'Verdana, Geneva, sans-serif' ) {
		$td_submenu_font_name = '|'.$td_submenu_font;

	} else {
		$td_submenu_font_name = '';

	}

    /*
    Translators: If there are characters in your language that are not supported
    by chosen font(s), translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !==  _x( 'on', 'Google font: on or off', 'jumbo' ) ) {
        $font_url = add_query_arg( 'family', urlencode( 'Roboto|Roboto Slab|Voltaire|Lato' . esc_html( $td_body_font_name ) . esc_html( $td_widgets_font_name ) . esc_html( $td_postpage_font_name ) . esc_html( $td_topmenu_font_name ) . esc_html( $td_mainmenu_font_name ) . esc_html( $td_submenu_font_name ) .':300,400,400italic,700italic,700&' .$td_subset ), "//fonts.googleapis.com/css" );

	}

    return $font_url;
}

/*----------------------------------------------------------------------------------------------------------
	 Add stylesheets to the generated page
-----------------------------------------------------------------------------------------------------------*/


if( !function_exists( 'jumbo_enqueue_css' ) ) {

	function jumbo_enqueue_css() {

		// THEME OPTIONS

		$theme 					= wp_get_theme();
		$jumbo 					= wp_get_theme( 'jumbo' );
		$template_directory_uri = get_template_directory_uri();
		$td_css_min 			= jumbo_get_option( 'td_css_minified' );

		// rtl conditional
		$rtl = ( is_rtl() ) ? '-rtl' : '';

        // css suffix
		if ( 1 == $td_css_min ) {
			$css_suffix = '.min';
		} else {
			$css_suffix = '';
		}
		// END OF THEME OPTIONS


        // Main theme stylesheet
		wp_enqueue_style( 'jumbo-style', $template_directory_uri . '/inc/css/style' .esc_html( $rtl ) . esc_html( $css_suffix ) . '.css', false, esc_html( $jumbo['Version'] ) );

		if( is_child_theme() ) {
			wp_enqueue_style( 'jumbo-child-style', get_stylesheet_uri(), false, esc_html( $theme['Version'] ) );
		}

		// ENQUEUE GOOGLE FONTS
		wp_enqueue_style( 'jumbo-fonts', jumbo_fonts_url(), array(), '1.0.0' );

	}
}

add_action( 'wp_enqueue_scripts', 'jumbo_enqueue_css' );


/*----------------------------------------------------------------------------------------------------------
	Enqueue Font Awesome
-----------------------------------------------------------------------------------------------------------*/

if ( ! function_exists( 'jumbo_font_awesome_css' ) ) {

	// this function can be completely overwritten using a child theme.
	function jumbo_font_awesome_css() {
		$td_uri = get_template_directory_uri() . '/inc/fonts/font-awesome/css/font-awesome.min.css';

		//	adding the 'font_awesome css_url' filter to change the url of the font (you may want to use CDN).
		$td_url = apply_filters( 'font_awesome_css_url', $td_uri );
		wp_enqueue_style( 'font-awesome', $td_url, false );
	}
}

add_action( 'wp_enqueue_scripts', 'jumbo_font_awesome_css' );


/*----------------------------------------------------------------------------------------------------------
	Enqueue theme JavaScripts
-----------------------------------------------------------------------------------------------------------*/

if( !function_exists( 'jumbo_enqueue_js' ) ) {

	function jumbo_enqueue_js() {

		global $is_IE; // WordPress-specific global variable for Internet Explorer

		$td_progressbar_enabled = jumbo_get_option( 'td_enable_progress_bar' );
		$td_uri 	= get_template_directory_uri();
		$jumbo		= wp_get_theme( 'jumbo' );
        $td_minified_js = jumbo_get_option( 'td_js_minified' );
		$rtl = ( is_rtl() ) ? '-rtl' : ''; // rtl conditional

        if ( true == $td_minified_js ) {
        	$td_js_directory = 'js-min';
        	$js_suffix = '.min';
        } else {
        	$td_js_directory = 'js';
        	$js_suffix = '';
        }

        // Enqueue external JavaScripts
		wp_enqueue_script( 'jumbo-theme-external', $td_uri . esc_html( '/inc/' ) . esc_html( $td_js_directory ) . '/jumbo-external-scripts' . esc_html( $rtl ) . esc_html( $js_suffix ) . '.js', array( 'jquery' ), esc_html( $jumbo['Version'] ), true );

        // Enqueue main theme script
        wp_enqueue_script( 'jumbo-theme-js', $td_uri . esc_html( '/inc/' ) . esc_html( $td_js_directory ) . '/jumbo-theme-scripts' . esc_html( $rtl ) . esc_html( $js_suffix ) . '.js', array( 'jquery' ), esc_html( $jumbo['Version'] ), true );

        // Enqueue game progressbar  script
        if ( defined( 'MYARCADE_VERSION' ) and is_game() and is_single() and $td_progressbar_enabled ) {
        	wp_enqueue_script( 'jumbo-progressbar-js', $td_uri . esc_html( '/inc/' ) . esc_html( $td_js_directory ) . '/jumbo-pregressbar' . esc_html( $js_suffix ) . '.js', array( 'jquery' ), esc_html( $jumbo['Version'] ), true );
        }

        // Enqueue comment reply
        if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        	wp_enqueue_script( 'comment-reply' );
        }
    }
}

add_action( 'wp_enqueue_scripts', 'jumbo_enqueue_js' );


/*----------------------------------------------------------------------------------------------------------
	Add a CSS class to body
-----------------------------------------------------------------------------------------------------------*/

function jumbo_add_class_to_body( $classes ) {

// add a class for vertical or horizontal game format
	global $post;
	if ( !is_search() ) {
		$select_game_type = get_post_meta( $post->ID, 'jumbo_game_type', true ); // get value of game type from metabox
	}

	if( defined( 'MYARCADE_VERSION' ) and is_game() and is_single() and $select_game_type == 'portrait' ) {
		$classes[] = 'jumbo-game-portrait';
	}

	if( is_front_page() ) {
		$classes[] = 'front-page';
	}

	if ( defined( 'MYARCADE_VERSION' ) and is_game() ) {
		$classes[] = 'td-games-page';
	}

	return $classes;
}

add_filter( 'body_class', 'jumbo_add_class_to_body' );


/*----------------------------------------------------------------------------------------------------------
	Add a class on body for differend options
-----------------------------------------------------------------------------------------------------------*/

if ( !function_exists( 'jumbo_smooth_class' ) ) {

	function jumbo_smooth_class( $classes ) {

		$td_cat_layout  	= jumbo_get_option( 'td_cat_layout2' );		// category layout

		if( $td_cat_layout == 'td_cat_2' ) {
			$classes[] = 'td-cat-layout-2';
		}

		return $classes;
	}
}

add_filter( 'body_class', 'jumbo_smooth_class' );


/*----------------------------------------------------------------------------------------------------------
	Add full width CSS class to body
-----------------------------------------------------------------------------------------------------------*/

function jumbo_full_width_class( $classes ) {

	// theme options
	$td_body_background_color = jumbo_get_option( 'td_body_background' );
	$td_body_background_image = jumbo_get_option( 'td_background_image' );

	if ( ( $td_body_background_color != '' and $td_body_background_color != 'ffffff' and $td_body_background_color != '#ffffff' ) or $td_body_background_image != '' ) {
		$classes[] = 'boxed-layout';
	} else {
		$classes[] = 'full-layout';
	}

	return $classes;
}

add_filter( 'body_class', 'jumbo_full_width_class' );



/*----------------------------------------------------------------------------------------------------------
	Add a login link and custom pages links to the right top menu
-----------------------------------------------------------------------------------------------------------*/

function jumbo_right_top_menu( $items, $args ) {


$td_latest_link 	= jumbo_get_option( 'td_latest_link' );
$td_hot_link 		= jumbo_get_option( 'td_hot_link' );
$td_popular_link 	= jumbo_get_option( 'td_popular_link' );

$td_latest_top 		= $td_latest_link;
$td_hot_top 		= $td_hot_link;
$td_popular_ltop 	= $td_popular_link;

if ( class_exists( 'simple_ajax_auth' ) ) {
		$td_logout_link = simple_ajax_auth_logout_link();
		$td_login_link 	= simple_ajax_auth_login_link();
	}


	if( $args->theme_location == 'top-menu') {

if( $td_latest_link ) {
		$items .= '<li class="menu-item td-top-latest" id="mobile-right-top-menu-1"><a href="' . esc_url( $td_latest_top ) . '">' . __jumbo_translate( 'latest' ) . '</a></li>';
	}
if( $td_hot_top ) {
		$items .= '<li class="menu-item td-top-hot" id="mobile-right-top-menu-2"><a href="' . esc_url( $td_hot_top ) . '">' . __jumbo_translate( 'hot' ) . '</a></li>';
	}
if( $td_popular_ltop ) {
		$items .= '<li class="menu-item td-top-popular" id="mobile-right-top-menu-3"><a href="' . esc_url( $td_popular_ltop ) . '">' . __jumbo_translate( 'popular' ) . '</a></li>';
	}

if ( class_exists( 'simple_ajax_auth' and wp_is_mobile() ) ) {
		$items .= '<li class="menu-item" id="mobile-right-top-menu-4">' . $td_logout_link . '</li>';
		$items .= '<li class="menu-item td-top-login" id="mobile-right-top-menu-5">' . $td_login_link . '</li>';
	}


if ( class_exists( 'simple_ajax_auth' ) ) {
		$items .= '<li class="menu-item" id="td-right-top-menu-1">' . $td_logout_link . '</li>';
		$items .= '<li class="menu-item" id="td-right-top-menu-2">' . $td_login_link . '</li>';
}

if( $td_popular_ltop ) {
		$items .= '<li class="menu-item td-top-popular" id="td-right-top-menu-3"><a href="' . esc_url( $td_popular_ltop ) . '">' . __jumbo_translate( 'popular' ) . '</a></li>';
	}
if( $td_hot_top ) {
		$items .= '<li class="menu-item td-top-hot" id="td-right-top-menu-4"><a href="' . esc_url( $td_hot_top ) . '">' . __jumbo_translate( 'hot' ) . '</a></li>';
	}
if( $td_latest_link ) {
		$items .= '<li class="menu-item td-top-latest" id="td-right-top-menu-5"><a href="' . esc_url( $td_latest_top ) . '">' . __jumbo_translate( 'latest' ) . '</a></li>';
	}

	}

	return $items;

}

add_filter( 'wp_nav_menu_items', 'jumbo_right_top_menu', 10, 2 );


/*----------------------------------------------------------------------------------------------------------
	Prints HTML with meta information for the current post date/time.
-----------------------------------------------------------------------------------------------------------*/

if( !function_exists( 'jumbo_posted_on' ) ) {

	function jumbo_posted_on() {

		// get all dates related to date
		$date_url   = get_permalink();
		$date_title = get_the_time();
		$date_time  = get_the_time();
		$date_time  = get_the_date( 'c' );
		$date       = get_the_date();



		// set the HTML for date link.
		$posted_on =
		'<div class="td-new-date"><a href="' . esc_url( $date_url ) . '" title="' . esc_attr( $date_title ) . '" rel="bookmark">
		<time class="entry-date" datetime="' . esc_attr( $date_time ) . '">' . esc_html( $date ) . '</time>
		</a></div>';

		echo wp_kses_post( $posted_on );
	}
}


/*----------------------------------------------------------------------------------------------------------
	Add meta entry category to single post, archive and blog list if set in theme options.
-----------------------------------------------------------------------------------------------------------*/

if( !function_exists( 'jumbo_posted_in' ) ) {

	function jumbo_posted_in() {

		// get value of 'post byline categories' toggle option from theme option for different pages
		if( is_single() ) {
			$show_categories = jumbo_get_option( 'td_single_byline_categories' );
		} else {
			$show_categories = 1;
		}

		if( $show_categories ) {
			$categories_list = get_the_category_list();
			if( $categories_list ) {
				$cats = sprintf( ' %1$s', $categories_list );
				?>
				<div class="cat-links"><?php echo wp_kses_post( $cats ); ?></div>
				<?php
			}
		}
	}
}


/*----------------------------------------------------------------------------------------------------------
	Add meta entry tags to single post, archive and blog list if set in theme options.
-----------------------------------------------------------------------------------------------------------*/

if( !function_exists( 'jumbo_post_tags' ) ) {

	function jumbo_post_tags() {

		// get value of 'post byline tags' toggle option from theme option for different pages
		if( is_single() ) {
			$show_tags = jumbo_get_option( 'td_single_byline_tags' );
		} else {
			$show_tags = 0;
		}

		if( $show_tags ) {
			$tags_list = get_the_tag_list();
			if( $tags_list ) {
				$tags_word = '<span class="td-tag-word">' . __jumbo_translate( 'post_tags' ) . '</span>';
				$print_tags = sprintf( $tags_word . ' %1$s', $tags_list );
				$show_the_tags = apply_filters( 'jumbo_box_tags', $print_tags );
				echo '<div class="tag-links">' . wp_kses_post( $show_the_tags ) . '</div>';
			}
		}
	}
}


/*----------------------------------------------------------------------------------------------------------
	Add tags box to the post
-----------------------------------------------------------------------------------------------------------*/

if( !function_exists( 'jumbo_tag_box' ) ) {

	function jumbo_tag_box() {

		global $post;
		$td_wp_tags 			= get_the_tag_list();
		$tags_word 				= '<span class="td-tag-word">' . __jumbo_translate( 'post_tags' ) . '</span>';
		$sprintf_tags 			= sprintf( $tags_word . ' %1$s', $td_wp_tags );
		$td_post_tags 			= apply_filters( 'jumbo_box_tags', $sprintf_tags );
		$td_show_post_tags 		= jumbo_get_option( 'td_single_post_tags' );

		$buffer = $td_our_post_tags = $buffer_post_tags = '' ;

		if( $td_wp_tags and $td_show_post_tags ) {
			$buffer_post_tags = '<div class="td-social-box-share tag-links"> ' . wp_kses_post( $td_post_tags ). '</div>';
		}

		$buffer .= '<div class="td-post-box-wrapper">' . wp_kses_post( $buffer_post_tags );

		echo wp_kses_post( $buffer ) . '</div>';

	}

}


/*----------------------------------------------------------------------------------------------------------
	Add meta entry comments link to single post, archive and blog list if set in theme options.
-----------------------------------------------------------------------------------------------------------*/

if( !function_exists( 'jumbo_comments_link' ) ) {

	function jumbo_comments_link() {

		if( !post_password_required() and comments_open() ) {
			?>

			<span class="comments-link">
				<?php comments_popup_link( '<i class="fa fa-comment-o"></i> 0', '<i class="fa fa-comment-o"></i> 1', '<i class="fa fa-comment-o"></i> %' ); ?>
			</span>

			<?php
		}
	}
}


/*----------------------------------------------------------------------------------------------------------
	Add meta entry views count to single post, archive and blog list if set in theme options.
-----------------------------------------------------------------------------------------------------------*/

if( !function_exists( 'jumbo_post_views' ) ) {

	function jumbo_post_views() {

		$buffer = '';

		// Check to see if "WP-PostViews" plugin is active then use it. "WP-PostViews" works great with "W3 Total Cache" and "Ajax_the_view"
		if ( function_exists( 'the_views' ) ) {
			$td_views_count = the_views(false);
			$buffer .= $td_views_count;
		}
		else {
			// Use the default theme views counter
			$buffer .= $td_views_count = jumbo_get_post_views( get_the_ID() ) ;
		} ?>

			<span class="post-views-count">
				<?php
				if ( defined( 'MYARCADE_VERSION' ) and is_game() ) {
					echo '<i class="fa fa-gamepad"></i>';
				}else{
					echo '<i class="fa fa-eye"></i>';
				}
				?>

			<span><?php echo wp_kses_post( $td_views_count ); ?></span>
			</span>

			<?php
	}
}

/*----------------------------------------------------------------------------------------------------------
	Display post format overlay icon
-----------------------------------------------------------------------------------------------------------*/
if( !function_exists( 'jumbo_post_format_icon' ) ) {

	function jumbo_post_format_icon() {

		if ( defined( 'MYARCADE_VERSION' ) and is_game() ) {
			$td_myarcade_post_format = '<i class="fa fa-gamepad"></i>';
		} else {
			$td_myarcade_post_format = '<i class="fa fa-file-text-o"></i>';
		}

		if ( has_post_format( 'video' ) ) {
			$td_post_format = '<i class="fa fa-youtube-play"></i>';
		}
		elseif ( has_post_format( 'image' ) ) {
			$td_post_format = '<i class="fa fa-picture-o"></i>';
		}
		else {

			$td_post_format = $td_myarcade_post_format;
		}
		$td_module_post_format = '<span class="image-overlay"></span><span class="module-overlay"><span class="post-format">' . wp_kses_post( $td_post_format ) . '</span></span>';
		 return $td_module_post_format;
	}
}


/*----------------------------------------------------------------------------------------------------------
	Display featured image caption on post.
-----------------------------------------------------------------------------------------------------------*/

if( !function_exists( 'jumbo_post_thumbnail_caption' ) ) {

	function jumbo_post_thumbnail_caption() {

		global $post;

		$td_attachment_id = get_post_thumbnail_id( $post->ID );
		$td_image_caption = get_post_field( 'post_excerpt', $td_attachment_id );

		if ( !empty( $td_image_caption ) ) {
			echo '<p class="wp-caption-text td-featured-image-caption">'. esc_html( $td_image_caption ) .'</p>';
		}
	}

}


/*----------------------------------------------------------------------------------------------------------
	Display featured image.
-----------------------------------------------------------------------------------------------------------*/

if( !function_exists( 'jumbo_featured_image' ) ) {

	function jumbo_featured_image() {

		global $post;
		$full_image = get_post_meta( $post->ID, 'jumbo_featured_image', true ); // get featured image option from meta box

		// get value of post featured image  from theme option, for different pages
		if( is_single() ) {

			$show_image_metabox = get_post_meta( $post->ID, 'jumbo_featured_image', true ); // get featured image option from meta box

			if ( $show_image_metabox == 'hide' ) {
				$show_image = false;

			} else {
				$show_image = jumbo_get_option( 'td_single_featured_images' );
			}

		}

		else {
			$show_image = 1;
		}

		if( $show_image && '' != get_the_post_thumbnail() ) { // if( has_post_thumbnail() )
			$td_feat_image = wp_get_attachment_image_src(get_post_thumbnail_id( $post->ID ), 'full');

			?>
			<div class="featured-image">

				<?php
				if ( defined( 'MYARCADE_VERSION' ) and is_game() ) {
					$jumbo_meta_color = '';
				} else {
					$jumbo_meta_color = jumbo_single_meta_color();
				}

				?>
				 <a class="td-popup-image" href="<?php echo esc_url( $td_feat_image[0] ); ?>" title="<?php the_title_attribute(); ?>" rel="bookmark">

				 	<?php if ( $full_image == 'full' ) : ?>
				 		<?php the_post_thumbnail( 'jumbo-full-featured' ) . esc_html( $jumbo_meta_color ); // initial code tweaked to fix adsense image position: === the_post_thumbnail( 'full', array( 'class' => 'left' ) ); === ?>
				 	<?php else : ?>
				 		<?php the_post_thumbnail( 'jumbo-featured-image' ) . esc_html( $jumbo_meta_color ); ?>
				 	<?php endif; ?>

				 	<?php jumbo_post_thumbnail_caption(); // featured image caption ?>

				</a>
			</div>
			<?php
		}
	}
}


/*----------------------------------------------------------------------------------------------------------
	Related posts module
-----------------------------------------------------------------------------------------------------------*/

if( !function_exists( 'jumbo_related_posts_module' ) ) {

	function jumbo_related_posts_module() {

		global $post;
		$td_the_title 		= get_the_title( $post->ID );
		$td_href 			= get_permalink( $post->ID );
		$categories_list 	= get_the_category_list();

		ob_start();
		?>

		<div class="td-related-box grid col-340">


			<div class="td-zoom-height">
				<a href="<?php echo esc_url( $td_href ); ?>" rel="bookmark" title="<?php echo esc_attr( strip_tags( $td_the_title ) ); ?>">


			<?php
			$placeholder_size =  '340x215.png';
			if( get_the_post_thumbnail() ) { // if( has_post_thumbnail() )
				$td_return_related_image = the_post_thumbnail( 'jumbo-modular-slider' );
			} else {

				$td_return_related_image = '<div class="td-noimage-fit-related"></div>';
			}
			echo wp_kses_post( $td_return_related_image );
			?>

			</a>

			<?php if( get_the_post_thumbnail() ) : ?>
			<?php jumbo_single_meta_color() ; ?>
		<?php endif;?>
		</div>
			<?php echo jumbo_get_post_title(); ?>

			<div class="post-meta">
				<div class="td-entry-count-views-box">
					<?php echo jumbo_review_final_score(); ?>
					<?php echo jumbo_posted_on(); ?>
				</div>
			</div>

		</div>

		<?php return ob_get_clean();
	}

}


/*----------------------------------------------------------------------------------------------------------
	Related post core function
-----------------------------------------------------------------------------------------------------------*/

if( !function_exists( 'jumbo_related_posts' ) ) {

	function jumbo_related_posts() {

		global $post;
		$td_related_post 		= jumbo_get_option( 'td_related_content' );
		$td_related_post_count 	= jumbo_get_option( 'td_related_content_count' );
		$category 				= get_the_category();
    	$category[0]->count;

		if ( !is_single() ) {
			return;
		}

		$tags = wp_get_post_tags( $post->ID );
		if ( $td_related_post == 0 or 1 == $category[0]->count or !$tags ) { // hide the related box if is disabled in theme options or there is only one post in a category, or the post has no tags
			return;
		}

		$buffer = '';

		$args = array();

		switch ( jumbo_get_option( 'td_related_content_type' ) ) {

            // related posts by tag
			case 'td_by_tag':
			$tags = wp_get_post_tags( $post->ID );

			if ( $tags ) {
				$taglist = array();
				for ($i = 0; $i <= 4; $i++) {
					if ( !empty( $tags[$i] ) ) {
						$taglist[] = $tags[$i]->term_id;
					} else {
						break;
					}
				}

				$args = array(
					'tag__in' => $taglist,
					'post__not_in' => array( $post->ID ),
					'showposts' => $td_related_post_count,
					'ignore_sticky_posts' => 1
					);
			}
			break;

            // related posts title
			case 'td_by_auth':
			$args = array(
				'author' => $post->post_author,
				'post__not_in' => array( $post->ID ),
				'showposts' => $td_related_post_count,
				'ignore_sticky_posts' => 1
				);
			break;

            // related posts by category
			default:
			$args = array(
				'category__in' => wp_get_post_categories( $post->ID ),
				'post__not_in' => array( $post->ID ),
				'showposts' => $td_related_post_count,
				'ignore_sticky_posts' => 1
				);

			break;
		}

		if ( !empty( $args ) ) {
            // do the query
			$td_query = new WP_Query( $args );
			if ( $td_query->have_posts() ) {

				$buffer .= '<div class="td-related-content">';
				$buffer .= '<div class="widget-title"><h3>' . __jumbo_translate( 'you_may_also_like' ) . '</h3></div>';

				while ( $td_query->have_posts() ) : $td_query->the_post();
				$buffer .= jumbo_related_posts_module();
				endwhile;

				$buffer .= '</div>';

			}
		}


		wp_reset_postdata();

		return $buffer;

	}
}


/*----------------------------------------------------------------------------------------------------------
	ADD CUSTOM MOBILE MENU TITLE USING THEME OPTIONS
-----------------------------------------------------------------------------------------------------------*/

if( !function_exists( 'jumbo_custom_mobile_menu_title' ) ) {

	function jumbo_custom_mobile_menu_title() {

		$td_custom_mobile_menu_title = JUMBO_Data::get( 'td_custom_mobile_menu_title' );

		if( isset( $td_custom_mobile_menu_title ) && $td_custom_mobile_menu_title != '' ) {
			echo '<span class="custom-mobile-menu-title">' . esc_html( $td_custom_mobile_menu_title ) . '</span>';

		} else {

			echo '<span class="custom-mobile-menu-title">' . __jumbo_translate( 'mobile_menu' ) . '</span>';
		}
	}
}

add_action( 'jumbo_header_bottom', 'jumbo_custom_mobile_menu_title' );


/*----------------------------------------------------------------------------------------------------------
	CHANGE DEFAULT TAG CLOUD TOOLTIP TO TAG NAME FOR SEO PURPOSES
-----------------------------------------------------------------------------------------------------------*/

function jumbo_change_tag_cloud_tooltip( $count, $tag ) {
	return $tag->name;
}


/*----------------------------------------------------------------------------------------------------------
	Add TGM Plugins Activator
-----------------------------------------------------------------------------------------------------------*/

// recommended plugins
add_action( 'tgmpa_register', 'jumbo_register_required_plugins' );

function jumbo_register_required_plugins() {

	$plugins = array(
		array(
			'name'     => esc_html__( 'WP-PageNavi', 'jumbo' ),
			'slug'     => 'wp-pagenavi',
			'required' => false,
			),
		array(
			'name'     => esc_html__( 'Mashshare Share Buttons', 'jumbo' ),
			'slug'     => 'mashsharer',
			'required' => false,
			'version'  => '',
			),
		array(
			'name'     => esc_html__( 'WP QUADS - Quick AdSense Reloaded', 'jumbo' ),
			'slug'     => 'quick-adsense-reloaded',
			'required' => false,
			),
		array(
			'name'     => esc_html__( 'Easy Custom Sidebars', 'jumbo' ),
			'slug'     => 'easy-custom-sidebars',
			'required' => false,
			),
		array(
			'name'     => esc_html__( 'MailChimp for WordPress', 'jumbo' ),
			'slug'     => 'mailchimp-for-wp',
			'required' => false,
			),
		array(
			'name'     => esc_html__( 'Menu Social Icons', 'jumbo' ),
			'slug'     => 'menu-social-icons',
			'required' => false,
			),
		array(
			'name'     => esc_html__( 'Simple Ajax Auth', 'jumbo' ),
			'slug'     => 'simple-ajax-auth',
			'required' => false,
			),
	    array(
	      'name'     => esc_html__( 'Simple Local Avatars', 'jumbo' ),
	      'slug'     => 'simple-local-avatars',
	      'required' => false,
	      ),
		array(
			'name'     => esc_html__( 'Contact form 7', 'jumbo' ),
			'slug'     => 'contact-form-7',
			'required' => false,
			),
		array(
			'name'     => esc_html__( 'I Recommend This', 'jumbo' ),
			'slug'     => 'i-recommend-this',
			'required' => false,
			),
		array(
                'name'					=> esc_html__( 'Jumbo Content Modules', 'jumbo' ), // The plugin name
                'slug'					=> 'jumbo-content-modules', // The plugin slug (typically the folder name)
                'source'				=> get_template_directory() . '/inc/plugins/jumbo-content-modules.zip', // The plugin source
                'required'				=> true, // If false, the plugin is only 'recommended' instead of required
                'version'				=> '1.0', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
                'force_activation'		=> false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
                'force_deactivation'	=> false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
                'external_url'			=> '', // If set, overrides default API URL and points to an external URL
                ),
		array(
                'name'					=> esc_html__( 'Custom Font Awesome 4 Menus', 'jumbo' ), // The plugin name
                'slug'					=> 'custom-font-awesome-4-menus', // The plugin slug (typically the folder name)
                'source'				=> get_template_directory() . '/inc/plugins/custom-font-awesome-4-menus.zip', // The plugin source
                'required'				=> false, // If false, the plugin is only 'recommended' instead of required
                'version'				=> '', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
                'force_activation'		=> false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
                'force_deactivation'	=> false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
                'external_url'			=> '', // If set, overrides default API URL and points to an external URL
                ),
		array(
                'name'					=> esc_html__( 'WPBakery Visual Composer', 'jumbo' ), // The plugin name
                'slug'					=> 'js_composer', // The plugin slug (typically the folder name)
                'source'				=> get_template_directory() . '/inc/plugins/js_composer.zip', // The plugin source
                'required'				=> true, // If false, the plugin is only 'recommended' instead of required
                'version'				=> '5.1.1', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
                'force_activation'		=> false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
                'force_deactivation'	=> false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
                'external_url'			=> '', // If set, overrides default API URL and points to an external URL
                ),
		array(
                'name'            		=> esc_html__( 'Taqyeem - WordPress Review Plugin', 'jumbo' ), // The plugin name
                'slug'            		=> 'taqyeem', // The plugin slug (typically the folder name)
                'source'          		=> get_template_directory() . '/inc/plugins/taqyeem.zip', // The plugin source
                'required'        		=> false, // If false, the plugin is only 'recommended' instead of required
                'version'         		=> '2.2.3', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
                'force_activation'    	=> false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
                'force_deactivation'  	=> false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
                'external_url'      	=> '', // If set, overrides default API URL and points to an external URL
                ),
		array(
                'name'            		=> esc_html__( 'Arqam - Social Counter Plugin', 'jumbo' ), // The plugin name
                'slug'            		=> 'arqam', // The plugin slug (typically the folder name)
                'source'          		=> get_template_directory() . '/inc/plugins/arqam.zip', // The plugin source
                'required'        		=> false, // If false, the plugin is only 'recommended' instead of required
                'version'         		=> '2.3.1', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
                'force_activation'    	=> false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
                'force_deactivation'  	=> false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
                'external_url'      	=> '', // If set, overrides default API URL and points to an external URL
                ),
		array(
                'name'     				=> esc_html__( 'Slider Revolution', 'jumbo' ), // The plugin name
                'slug'     				=> 'revslider', // The plugin slug (typically the folder name)
                'source'   				=> get_template_directory() . '/inc/plugins/revslider.zip', // The plugin source
                'required' 				=> false, // If false, the plugin is only 'recommended' instead of required
                'version' 				=> '5.4.5.1', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
                'force_activation' 		=> false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
                'force_deactivation' 	=> false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
                'external_url' 			=> '', // If set, overrides default API URL and points to an external URL
                ),
		array(
                'name'     				=> esc_html__( 'JPS Ajax Post Layout', 'jumbo' ), // The plugin name
                'slug'     				=> 'JPS-Ajax-Post-Layout', // The plugin slug (typically the folder name)
                'source'   				=> get_template_directory() . '/inc/plugins/JPS-Ajax-Post-Layout.zip', // The plugin source
                'required' 				=> false, // If false, the plugin is only 'recommended' instead of required
                'version' 				=> '1.9.0.7', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
                'force_activation' 		=> false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
                'force_deactivation' 	=> false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
                'external_url' 			=> '', // If set, overrides default API URL and points to an external URL
                )
		);

/**
 * Array of configuration settings. Amend each line as needed.
 * If you want the default strings to be available under your own theme domain, leave the strings uncommented.
 * Some of the strings are added into a sprintf, so see the comments at the end of each line for what each argument will be.
 */

	$config = array(
		'id'           => 'jumbo',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.


		'strings'      => array(
			'page_title'                      => esc_html__( 'Install Required Plugins', 'jumbo' ),
			'menu_title'                      => esc_html__( 'Install Plugins', 'jumbo' ),
			'installing'                      => esc_html__( 'Installing Plugin: %s', 'jumbo' ), // %s = plugin name.
			'oops'                            => esc_html__( 'Something went wrong with the plugin API.', 'jumbo' ),
			'notice_can_install_required'     => _n_noop(
				'This theme requires the following plugin: %1$s.',
				'This theme requires the following plugins: %1$s.',
				'jumbo'
			), // %1$s = plugin name(s).
			'notice_can_install_recommended'  => _n_noop(
				'This theme recommends the following plugin: %1$s.',
				'This theme recommends the following plugins: %1$s.',
				'jumbo'
			), // %1$s = plugin name(s).
			'notice_cannot_install'           => _n_noop(
				'Sorry, but you do not have the correct permissions to install the %1$s plugin.',
				'Sorry, but you do not have the correct permissions to install the %1$s plugins.',
				'jumbo'
			), // %1$s = plugin name(s).
			'notice_ask_to_update'            => _n_noop(
				'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.',
				'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.',
				'jumbo'
			), // %1$s = plugin name(s).
			'notice_ask_to_update_maybe'      => _n_noop(
				'There is an update available for: %1$s.',
				'There are updates available for the following plugins: %1$s.',
				'jumbo'
			), // %1$s = plugin name(s).
			'notice_cannot_update'            => _n_noop(
				'Sorry, but you do not have the correct permissions to update the %1$s plugin.',
				'Sorry, but you do not have the correct permissions to update the %1$s plugins.',
				'jumbo'
			), // %1$s = plugin name(s).
			'notice_can_activate_required'    => _n_noop(
				'The following required plugin is currently inactive: %1$s.',
				'The following required plugins are currently inactive: %1$s.',
				'jumbo'
			), // %1$s = plugin name(s).
			'notice_can_activate_recommended' => _n_noop(
				'The following recommended plugin is currently inactive: %1$s.',
				'The following recommended plugins are currently inactive: %1$s.',
				'jumbo'
			), // %1$s = plugin name(s).
			'notice_cannot_activate'          => _n_noop(
				'Sorry, but you do not have the correct permissions to activate the %1$s plugin.',
				'Sorry, but you do not have the correct permissions to activate the %1$s plugins.',
				'jumbo'
			), // %1$s = plugin name(s).
			'install_link'                    => _n_noop(
				'Begin installing plugin',
				'Begin installing plugins',
				'jumbo'
			),
			'update_link' 					  => _n_noop(
				'Begin updating plugin',
				'Begin updating plugins',
				'jumbo'
			),
			'activate_link'                   => _n_noop(
				'Begin activating plugin',
				'Begin activating plugins',
				'jumbo'
			),
			'return'                          => esc_html__( 'Return to Required Plugins Installer', 'jumbo' ),
			'plugin_activated'                => esc_html__( 'Plugin activated successfully.', 'jumbo' ),
			'activated_successfully'          => esc_html__( 'The following plugin was activated successfully:', 'jumbo' ),
			'plugin_already_active'           => esc_html__( 'No action taken. Plugin %1$s was already active.', 'jumbo' ),  // %1$s = plugin name(s).
			'plugin_needs_higher_version'     => esc_html__( 'Plugin not activated. A higher version of %s is needed for this theme. Please update the plugin.', 'jumbo' ),  // %1$s = plugin name(s).
			'complete'                        => esc_html__( 'All plugins installed and activated successfully. %1$s', 'jumbo' ), // %s = dashboard link.
			'contact_admin'                   => esc_html__( 'Please contact the administrator of this site for help.', 'jumbo' ),

			'nag_type'                        => 'updated', // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
		),

	);

global $pagenow;
  // Add TGMPA plugin notification only on wp-admin/themes.php
   if ( current_user_can( 'manage_options' ) && 'themes.php' == $pagenow ) {
    tgmpa( $plugins, $config );
  }
}