<?php

// If this file is called directly, busted!
if( !defined( 'ABSPATH' ) ) {
	exit;
}

/*----------------------------------------------------------------------------------------------------------
	THEME CUSTOM POST META
-----------------------------------------------------------------------------------------------------------*/


/*----------------------------------------------------
	Get content classes
-----------------------------------------------------*/

function jumbo_get_content_classes() {
	$content_classes = array();
	$layout          = jumbo_get_layout();
	if( in_array( $layout, array( 'default', 'content-sidebar-page' ) ) ) {
		$content_classes[] = 'grid';
		$content_classes[] = 'col-728 td-default-page';
	}
	elseif( 'sidebar-content-page' == $layout ) {
		$content_classes[] = 'grid-right';
		$content_classes[] = 'col-728';
		$content_classes[] = 'fit';
	}
	elseif( 'content-sidebar-half-page' == $layout ) {
		$content_classes[] = 'grid';
		$content_classes[] = 'col-534';
	}
	elseif( 'sidebar-content-half-page' == $layout ) {
		$content_classes[] = 'grid-right';
		$content_classes[] = 'col-534';
		$content_classes[] = 'fit';
	}
	elseif( 'full-width-page' == $layout ) {
		$content_classes[] = 'grid';
		$content_classes[] = 'col-1116';
	}

	return apply_filters( 'jumbo_content_classes', $content_classes );
}


/*----------------------------------------------------
	Get sidebar classes
-----------------------------------------------------*/

function jumbo_get_sidebar_classes() {
	$sidebar_classes = array();
	$layout          = jumbo_get_layout();
	if( in_array( $layout, array( 'default', 'content-sidebar-page' ) ) ) {
		$sidebar_classes[] = 'grid';
		$sidebar_classes[] = 'col-340';
		$sidebar_classes[] = 'fit';
	}
	elseif( 'sidebar-content-page' == $layout ) {
		$sidebar_classes[] = 'grid-right';
		$sidebar_classes[] = 'col-340';
		$sidebar_classes[] = 'rtl-fit';
	}
	elseif( 'content-sidebar-half-page' == $layout ) {
		$sidebar_classes[] = 'grid';
		$sidebar_classes[] = 'col-534';
		$sidebar_classes[] = 'fit';
	}
	elseif( 'sidebar-content-half-page' == $layout ) {
		$sidebar_classes[] = 'grid-right';
		$sidebar_classes[] = 'col-534';
		$sidebar_classes[] = 'rtl-fit';

	}

	return apply_filters( 'jumbo_sidebar_classes', $sidebar_classes );
}


/*----------------------------------------------------
	Get current layout
-----------------------------------------------------*/

function jumbo_get_layout() {

	// 404 pages
	if( is_404() ) {
		return 'default';
	}

	$layout = '';

	// Get valid layouts
	$valid_layouts = jumbo_get_valid_layouts();

	$td_blog_posts_index_layout_default = JUMBO_Data::get( 'td_blog_posts_index_layout_default' );
	$td_static_page_layout_default 		= JUMBO_Data::get( 'td_static_page_layout_default' );
	$td_single_post_layout_default 		= JUMBO_Data::get( 'td_single_post_layout_default' );
	// For singular pages, get post meta
	if( is_singular() ) {
		global $post;
		$layout_meta_value = ( false != get_post_meta( $post->ID, '_jumbo_layout', true ) ? get_post_meta( $post->ID, '_jumbo_layout', true ) : 'default' );
		$layout_meta       = ( array_key_exists( $layout_meta_value, $valid_layouts ) ? $layout_meta_value : 'default' );
	}

	// Static pages
	if( is_page() ) {
		$page_template = get_post_meta( $post->ID, '_wp_page_template', true );

		// If custom page template is defined, use it first
		if( 'default' != $page_template ) {
			if( in_array( $page_template, array( 'blog.php', 'blog-excerpt.php' ) ) ) {
				$layout = $td_blog_posts_index_layout_default;
			} else {
				$layout = $td_static_page_layout_default ;
			}
		} elseif( 'default' != $layout_meta ) { // Else, if post custom meta is set, use it
			$layout = $layout_meta;

		} else { // Else, use the default
			$layout = $td_static_page_layout_default;
		}

	} else { // Single blog posts
		if( is_single() ) {
			// If post custom meta is set, use it
			if( 'default' != $layout_meta ) {
				$layout = $layout_meta;
			} else { // Else, use the default
				$layout = $td_single_post_layout_default ;
			}

		} elseif( is_home() || is_archive() || is_search() ) { // Posts index
			$layout = $td_blog_posts_index_layout_default;
		} else { // Fallback Layout
			$layout = 'default';
		}

	}

	return apply_filters( 'jumbo_get_layout', $layout );
}


/*----------------------------------------------------
	Get Post layouts
-----------------------------------------------------*/

function jumbo_get_valid_layouts() {

	$layouts = array(
		'default'                   => esc_html__( 'Default Layout', 'jumbo' ),
		'content-sidebar-page'      => esc_html__( 'Content - Right Sidebar', 'jumbo' ),
		'sidebar-content-page'      => esc_html__( 'Left Sidebar - Content', 'jumbo' ),
		'full-width-page'           => esc_html__( 'Full Width (no sidebar)', 'jumbo' )
	);

	return apply_filters( 'jumbo_valid_layouts', $layouts );
}


/*----------------------------------------------------
	Add Layout Meta Box
-----------------------------------------------------*/

function jumbo_add_layout_meta_box( $post ) { // layout on post edit page

	global $post, $wp_meta_boxes;

	$context  = apply_filters( 'jumbo_layout_meta_box_context', 'side' ); // 'normal', 'side', 'advanced'
	$priority = apply_filters( 'jumbo_layout_meta_box_priority', 'default' ); // 'high', 'core', 'low', 'default'

	add_meta_box(
		'jumbo_layout',
		__( 'Layout', 'jumbo' ),
		'jumbo_layout_meta_box',
		'post',
		$context,
		$priority
	);
}

// Hook meta boxes into 'add_meta_boxes'
add_action( 'add_meta_boxes', 'jumbo_add_layout_meta_box' );


/*----------------------------------------------------
	Define Layout Meta Box
-----------------------------------------------------*/

function jumbo_layout_meta_box() {

	global $post;
	$custom        = ( get_post_custom( $post->ID ) ? get_post_custom( $post->ID ) : false );
	$layout        = ( isset( $custom['_jumbo_layout'][0] ) ? $custom['_jumbo_layout'][0] : 'default' );
	$valid_layouts = jumbo_get_valid_layouts();
	?>
	<p>
		<select name="_jumbo_layout">
			<?php foreach( $valid_layouts as $slug => $name ) { ?>
			<?php $selected = selected( $layout, $slug, false ); ?>
			<option value="<?php echo esc_html( $slug ); ?>" <?php echo esc_html( $selected ); ?>><?php echo esc_html( $name ); ?></option>
			<?php } ?>
		</select>
	</p>
	<?php
}


/*----------------------------------------------------
	Validate, sanitize, and save post metadata.
-----------------------------------------------------*/

function jumbo_save_layout_post_metadata() {

	global $post;

	if( !isset( $post ) || !is_object( $post ) ) {
		return;
	}

	// If the selected layout option isn't in the array of valid layout, returns 'default'.
	$valid_layouts = jumbo_get_valid_layouts();
	$layout        = ( isset( $_POST['_jumbo_layout'] ) && array_key_exists( $_POST['_jumbo_layout'], $valid_layouts ) ? $_POST['_jumbo_layout'] : 'default' );

	update_post_meta( $post->ID, '_jumbo_layout', $layout );
}

// Hook the save layout post custom meta data into publish_{post-type}, draft_{post-type}, and future_{post-type}
add_action( 'publish_post', 'jumbo_save_layout_post_metadata' );
add_action( 'publish_page', 'jumbo_save_layout_post_metadata' );
add_action( 'draft_post', 'jumbo_save_layout_post_metadata' );
add_action( 'draft_page', 'jumbo_save_layout_post_metadata' );
add_action( 'future_post', 'jumbo_save_layout_post_metadata' );
add_action( 'future_page', 'jumbo_save_layout_post_metadata' );


/*----------------------------------------------------------------------------------------------------------
	Add a Featured Image Show/Hide Meta Box on the post editor screen
-----------------------------------------------------------------------------------------------------------*/

// Fire our meta box setup function on the post editor screen
add_action( 'load-post.php', 'jumbo_post_meta_boxes_setup' );
add_action( 'load-post-new.php', 'jumbo_post_meta_boxes_setup' );


/*----------------------------------------------------
	Meta box setup function
-----------------------------------------------------*/

if ( ! function_exists( 'jumbo_post_meta_boxes_setup' ) ) {

	function jumbo_post_meta_boxes_setup() {

	// Add meta boxes on the 'add_meta_boxes' hook
		add_action( 'add_meta_boxes', 'jumbo_add_post_meta_boxes' );

	// Save post meta on the 'save_post' hook
		add_action( 'save_post', 'jumbo_save_featured_image_meta', 10, 2 );
		add_action( 'save_post', 'jumbo_save_game_type_meta', 10, 2 );

	}

}


/*----------------------------------------------------
	Create the meta box for post editor screen
-----------------------------------------------------*/

if ( ! function_exists( 'jumbo_add_post_meta_boxes' ) ) {

	function jumbo_add_post_meta_boxes() {

	$context  = apply_filters( 'jumbo_featured_image_meta_box_context', 'side' ); 	// 'normal', 'side', 'advanced'
	$priority = apply_filters( 'jumbo_featured_image_meta_box_priority', 'default' ); // 'high', 'core', 'low', 'default'
	$context  = apply_filters( 'jumbo_game_type_meta_box_context', 'side' ); 	// 'normal', 'side', 'advanced'
	$priority = apply_filters( 'jumbo_game_type_meta_box_priority', 'default' ); // 'high', 'core', 'low', 'default'

	add_meta_box(
			'jumbo-featured-image',									// Unique ID
			esc_html__( 'Featured Image', 'jumbo' ),				// Title
			'jumbo_featured_image_meta_box',						// Callback function
			'post',													// Admin page (or post type)
			$context,												// Context
			$priority												// Priority
			);

	if ( defined( 'MYARCADE_VERSION' ) and is_game() ) {

		add_meta_box(
			'jumbo-game-type',										// Unique ID
			esc_html__( 'Game Format', 'jumbo' ),					// Title
			'jumbo_game_type_meta_box',								// Callback function
			'post',													// Admin page (or post type)
			$context,												// Context
			$priority												// Priority
			);
		}

	}

}


/*----------------------------------------------------
	The featured image post meta box
-----------------------------------------------------*/

if ( !function_exists( 'jumbo_featured_image_meta_box' ) ) {

	function jumbo_featured_image_meta_box( $object, $box ) { ?>

	<?php wp_nonce_field( basename( __FILE__ ), 'jumbo_featured_image_nonce' ); $selected = esc_html( get_post_meta( $object->ID, 'jumbo_featured_image', true ) ); ?>
	<p>
		<select class="widefat" name="jumbo-featured-image" id="jumbo-featured-image">
			<option value="show" <?php selected( $selected, 'show' ); ?>>Show</option>
			<option value="hide" <?php selected( $selected, 'hide' ); ?>>Hide</option>
			<option value="full" <?php selected( $selected, 'full' ); ?>>Full Width</option>
		</select>
		<label for="jumbo-featured-image">
			<div class="howto"><?php esc_html_e( "This option may be overridden by theme options. Please note that even if you have chosen to hide the featured image for this post, you still have to set a featured image below to be used in other areas of the site.", 'jumbo' ); ?>
			</div></label>
	</p>

	<?php }

}


/*----------------------------------------------------
	The gametype meta box
-----------------------------------------------------*/

if ( !function_exists( 'jumbo_game_type_meta_box' ) ) {

	function jumbo_game_type_meta_box( $object, $box ) { ?>

	<?php wp_nonce_field( basename( __FILE__ ), 'jumbo_game_type_nonce' ); $selected = esc_html( get_post_meta( $object->ID, 'jumbo_game_type', true ) ); ?>
	<p>
		<select class="widefat" name="jumbo-game-type" id="jumbo-game-type">
			<option value="landscape" <?php selected( $selected, 'landscape' ); ?>>Landscape</option>
			<option value="portrait" <?php selected( $selected, 'portrait' ); ?>>Portrait</option>
		</select>
			<label for="jumbo-game-type">
			<div class="howto"><?php esc_html_e( "If this game is deigned for phones in vertical position, then select Portrait. If the game is designed for desktop in landscape format, then select Landscape. See How Tos menu from theme documentation for more info.", 'jumbo' ); ?></div>
			</label>
	</p>

	<?php }

}

/*----------------------------------------------------
	Save the meta box's post metadata
-----------------------------------------------------*/

if ( !function_exists( 'jumbo_save_game_type_meta' ) ) {

	function jumbo_save_game_type_meta( $post_id, $post ) {

		// Verify the nonce before proceeding
		if ( !isset( $_POST['jumbo_game_type_nonce'] ) || !wp_verify_nonce( $_POST['jumbo_game_type_nonce'], basename( __FILE__ ) ) ) {
			return $post_id;
		}

		// Get the post type object
		$post_type = get_post_type_object( $post->post_type );

		// Check if the current user has permission to edit the post
		if ( !current_user_can( $post_type->cap->edit_post, $post_id ) ) {
			return $post_id;
		}

		// Get the posted data and sanitize it for use as an HTML class
		$new_meta_value = ( isset( $_POST['jumbo-game-type'] ) ? balanceTags( $_POST['jumbo-game-type'] ) : '' );

		// Get the meta key
		$meta_key = 'jumbo_game_type';

		// Get the meta value of the custom field key
		$meta_value = get_post_meta( $post_id, $meta_key, true );

		// If a new meta value was added and there was no previous value, add it
		if ( $new_meta_value && '' == $meta_value ) {
			add_post_meta( $post_id, $meta_key, $new_meta_value, true );
		}

		// If the new meta value does not match the old value, update it
		elseif ( $new_meta_value && $new_meta_value != $meta_value ) {
			update_post_meta( $post_id, $meta_key, $new_meta_value );
		}

		// If there is no new meta value but an old value exists, delete it
		elseif ( '' == $new_meta_value && $meta_value ) {
			delete_post_meta( $post_id, $meta_key, $meta_value );
		}

	}

}

/*----------------------------------------------------
	Save the meta box's post metadata
-----------------------------------------------------*/

if ( !function_exists( 'jumbo_save_featured_image_meta' ) ) {

	function jumbo_save_featured_image_meta( $post_id, $post ) {

		// Verify the nonce before proceeding
		if ( !isset( $_POST['jumbo_featured_image_nonce'] ) || !wp_verify_nonce( $_POST['jumbo_featured_image_nonce'], basename( __FILE__ ) ) ) {
			return $post_id;
		}

		// Get the post type object
		$post_type = get_post_type_object( $post->post_type );

		// Check if the current user has permission to edit the post
		if ( !current_user_can( $post_type->cap->edit_post, $post_id ) ) {
			return $post_id;
		}

		// Get the posted data and sanitize it for use as an HTML class
		$new_meta_value = ( isset( $_POST['jumbo-featured-image'] ) ? balanceTags( $_POST['jumbo-featured-image'] ) : '' );

		// Get the meta key
		$meta_key = 'jumbo_featured_image';

		// Get the meta value of the custom field key
		$meta_value = get_post_meta( $post_id, $meta_key, true );

		// If a new meta value was added and there was no previous value, add it
		if ( $new_meta_value && '' == $meta_value ) {
			add_post_meta( $post_id, $meta_key, $new_meta_value, true );
		}

		// If the new meta value does not match the old value, update it
		elseif ( $new_meta_value && $new_meta_value != $meta_value ) {
			update_post_meta( $post_id, $meta_key, $new_meta_value );
		}

		// If there is no new meta value but an old value exists, delete it
		elseif ( '' == $new_meta_value && $meta_value ) {
			delete_post_meta( $post_id, $meta_key, $meta_value );
		}

	}

}