<?php
/*----------------------------------------------------------------------------------------------------------
  Jumbo_Module_Carousel widget class
-----------------------------------------------------------------------------------------------------------*/
class Jumbo_Module_Carousel extends WP_Widget {


/*----------------------------------------------------------------------------------------------------------
  Register widget with WordPress
-----------------------------------------------------------------------------------------------------------*/

function __construct() {
  parent::__construct(
      'jumbo_module_carousel', // Base Widget ID
      esc_html__( '[TD] Post Layout 1', 'jumbo' ), // Widget Name
      array( 'description' => esc_html__( 'A widget that display posts using an ajax carousel.', 'jumbo' ), ) // Widget Args
      );
}


/*----------------------------------------------------------------------------------------------------------
Front-end display of widget
-----------------------------------------------------------------------------------------------------------*/

public function widget( $args, $instance ) {
extract( $args );

$title          = apply_filters( 'widget_title', $instance['title'] );
$condition      = apply_filters ( 'condition', isset ( $instance ['condition'] ) ? $instance ['condition'] : '' );
$sortby         = apply_filters ( 'sortby', isset ( $instance ['sortby'] ) ? $instance ['sortby'] : '' );
$autoplay       = apply_filters ( 'autoplay', isset ( $instance ['autoplay'] ) ? $instance ['autoplay'] : '' );
$total_posts    = $instance['total_posts'];
$posts_per_page = $instance['posts_per_page'];
$categories     = $instance['categories'];


echo wp_kses_post( $before_widget );
?>




<?php // =============================== MAIN BLOCK =============================== ?>

<?php if ( $title ) : ?>
<div class="widget-title">
<h3>

  <?php echo esc_html( $title ); ?>

</h3>
</div>
<?php endif; ?>

<div class="td-wrap-content-sidebar">


<?php
// ----------- CONTENT
// ---------------------------------------------------------------------------
?>


<div class="td-fly-in">

<?php $td_vc_jps_addon = '[jps_bete_sc style=bt-carousel-2 autoplay= '. $autoplay .' categories= '. $categories .' sortby= '. $sortby .' condition= '. $condition .' total_posts= '. $total_posts .' items_per_page= '. $posts_per_page .']' ; ?>
<?php echo do_shortcode( $td_vc_jps_addon ); ?>

</div><?php // end of .td-fly-in ?>



</div><?php // end of td-wrap-content-sidebar ?>


<?php echo wp_kses_post( $after_widget );

}

/*----------------------------------------------------------------------------------------------------------
  Sanitize widget form values as they are saved
-----------------------------------------------------------------------------------------------------------*/

public function update( $new_instance, $old_instance ) {
$instance = array();
$instance                           = $old_instance;
$instance['title']                  = strip_tags( $new_instance['title'] );
$instance['total_posts']            = $new_instance['total_posts'];
$instance['posts_per_page']         = $new_instance['posts_per_page'];
$instance['categories']             = $new_instance['categories'];
$instance['condition']              = strip_tags( $new_instance['condition'] );
$instance['sortby']                 = strip_tags( $new_instance['sortby'] );
$instance['autoplay']               = strip_tags( $new_instance['autoplay'] );

return $instance;
}


/*----------------------------------------------------------------------------------------------------------
  Back-end widget form
-----------------------------------------------------------------------------------------------------------*/

public function form( $instance ) {
$defaults = array(
'title'               => 'Recent Posts',
'total_posts'         => 12,
'posts_per_page'      => 4,
'condition'           => 'latest',
'sortby'              => 'DESC',
'autoplay'            => 'no',
'categories'              => ''
);

$condition  = isset ( $instance ['condition'] ) ? $instance ['condition'] : '';
$sortby     = isset ( $instance ['sortby'] ) ? $instance ['sortby'] : '';
$autoplay   = isset ( $instance ['autoplay'] ) ? $instance ['autoplay'] : '';
$instance   = wp_parse_args( (array) $instance, $defaults );



/*----------------------------------------------------------------------------------------------------------
  Widget Options
-----------------------------------------------------------------------------------------------------------*/
?>

<p>
<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'jumbo' ); ?></label>
<input class="widefat" type="text" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
</p>



<p>
<label for="<?php echo esc_attr( $this->get_field_id( 'total_posts' ) ); ?>"><?php esc_html_e( 'Total Posts:', 'jumbo' ); ?></label>
<input id="<?php echo esc_attr( $this->get_field_id('total_posts') ); ?>"  class="widefat" type="text" name="<?php echo esc_attr( $this->get_field_name('total_posts') ); ?>" value="<?php echo esc_attr( $instance['total_posts'] ); ?>" />
</p>

<p>
<label for="<?php echo esc_attr( $this->get_field_id( 'posts_per_page' ) ); ?>"><?php esc_html_e( 'Number of posts to display:', 'jumbo' ); ?></label>
<input id="<?php echo esc_attr( $this->get_field_id('posts_per_page') ); ?>"  class="widefat" type="text" name="<?php echo esc_attr( $this->get_field_name('posts_per_page') ); ?>" value="<?php echo esc_attr( $instance['posts_per_page'] ); ?>" />
</p>


<p>
<label for="<?php echo esc_attr( $this->get_field_id( 'condition' ) ); ?>"><?php esc_html_e( 'Sort order:', 'jumbo' ); ?></label>
<select id="<?php echo esc_attr( $this->get_field_id( 'condition' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'condition' ) ); ?>" class="widefat">
<option value="latest"<?php if( $condition=="latest" ) echo ' selected="selected"';?>><?php esc_html_e( 'Latest', 'jumbo' );?></option>
<option value="mostcommented"<?php if( $condition=="mostcommented" ) echo ' selected="selected"';?>><?php esc_html_e( 'Popular Posts', 'jumbo' );?></option>
<option value="title"<?php if( $condition=="title" ) echo ' selected="selected"';?>><?php esc_html_e( 'Title', 'jumbo' );?></option>
</select>
</p>

<p>
<label for="<?php echo esc_attr( $this->get_field_id( 'sortby' ) ); ?>"><?php esc_html_e( 'Sort by:', 'jumbo' ); ?></label>
<select id="<?php echo esc_attr( $this->get_field_id( 'sortby' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'sortby' ) ); ?>" class="widefat">
<option value="DESC"<?php if( $sortby=="DESC" ) echo ' selected="selected"';?>><?php esc_html_e( 'DESC', 'jumbo' );?></option>
<option value="ASC"<?php if( $sortby=="ASC" ) echo ' selected="selected"';?>><?php esc_html_e( 'ASC', 'jumbo' );?></option>
</select>
</p>

<p>
<label for="<?php echo esc_attr( $this->get_field_id( 'autoplay' ) ); ?>"><?php esc_html_e( 'Autoplay Corousel:', 'jumbo' ); ?></label>
<select id="<?php echo esc_attr( $this->get_field_id( 'autoplay' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'autoplay' ) ); ?>" class="widefat">
<option value="no"<?php if( $autoplay=="no" ) echo ' selected="selected"';?>><?php esc_html_e( 'No', 'jumbo' );?></option>
<option value="yes"<?php if( $autoplay=="yes" ) echo ' selected="selected"';?>><?php esc_html_e( 'Yes', 'jumbo' );?></option>
</select>
</p>

<?php
}

}

/*----------------------------------------------------------------------------------------------------------
  Register Jumbo_Module_Carousel widget
-----------------------------------------------------------------------------------------------------------*/

function jumbo_module_carousel_init(){
register_widget( 'Jumbo_Module_Carousel' );
}

add_action( 'widgets_init', 'jumbo_module_carousel_init' );