<?php

/*----------------------------------------------------------------------------------------------------------
  Widget class
-----------------------------------------------------------------------------------------------------------*/
class Jumbo_Tag_Cloud_Widget extends WP_Widget {


/*----------------------------------------------------------------------------------------------------------
  Register widget with WordPress
-----------------------------------------------------------------------------------------------------------*/

    public function __construct() {
        parent::__construct(
            'jumbo_tag_cloud_widget',
            esc_html__( '[TD] Tag Cloud', 'jumbo' ), // Widget Name
            array( 'description' => esc_html__( 'A SEO optimized cloud of your most popular tags.', 'jumbo' ), ) // Widget Args
            );
    }


/*----------------------------------------------------------------------------------------------------------
  Front-end display of widget
-----------------------------------------------------------------------------------------------------------*/

public function widget( $args, $instance ) {
    extract( $args );
    $title          = apply_filters( 'widget_title', $instance['title'] );
    $tags_count     = $instance['td_tags_number'];
    $tags_taxonomy  = $instance['td_taxonomy'];

    $td_tag_colored = ! empty( $instance['td_tag_colored'] ) ? '1' : '0';
    $td_tag_display = ! empty( $instance['td_tag_display'] ) ? '1' : '0';

    if ( $td_tag_colored ) {
            $td_colored_tag = 'td-tag-colored';
        }
        else {
            $td_colored_tag = '';
        }
        if ( $td_tag_display ) {
            $td_tag_inline = 'td-tag-cloud-full-length';
        }
        else {
            $td_tag_inline = 'td-tag-cloud-inline';
        }

        echo wp_kses_post( $before_widget );
        if ( $instance['title'] ) {
            echo wp_kses_post( $before_title . $title . $after_title );
        }
        ?>

<div class="td-fly-in">
    <div class="td-tag-cloud-widget <?php echo esc_html( $td_colored_tag ); ?> <?php echo esc_html( $td_tag_inline ); ?>">
        <?php
        $tags = wp_tag_cloud( array(
            'number'                    => $tags_count,
            'taxonomy'                  => $tags_taxonomy,
            'orderby'                   => 'count',
            'order'                     => 'RAND',
            'topic_count_text_callback' => 'jumbo_change_tag_cloud_tooltip',
            ) );

        echo wp_kses_post( $tags );
        ?>

    </div>
</div>
    <?php
    echo wp_kses_post( $after_widget );

    }


/*----------------------------------------------------------------------------------------------------------
  Sanitize widget form values as they are saved
-----------------------------------------------------------------------------------------------------------*/

    public function update( $new_instance, $old_instance ) {
        $instance = array();
        $instance['title']          = strip_tags( $new_instance['title'] );
        $instance['td_tags_number'] = esc_attr( $new_instance['td_tags_number'] );
        $instance['td_tag_colored'] = !empty($new_instance['td_tag_colored']) ? 1 : 0;
        $instance['td_tag_display'] = !empty($new_instance['td_tag_display']) ? 1 : 0;
        $instance['td_taxonomy']    = esc_attr( $new_instance['td_taxonomy'] );
        return $instance;
    }


/*----------------------------------------------------------------------------------------------------------
  Back-end widget form
-----------------------------------------------------------------------------------------------------------*/

    public function form( $instance ) {
        if ( isset( $instance[ 'title' ] ) ) {
            $title = $instance[ 'title' ];
        }
        else {
            $title = esc_html__( 'Tag Cloud', 'jumbo' );
        }

        if ( isset( $instance[ 'td_tags_number' ] ) ) {
            $tags_count = $instance[ 'td_tags_number' ];
        }
        else {
            $tags_count = 8;
        }
        if ( isset( $instance[ 'td_taxonomy' ] ) ) {
            $tags_taxonomy = $instance[ 'td_taxonomy' ];
        }
        else {
            $tags_taxonomy = 'post_tag';
        }
        $td_tag_colored = isset( $instance['td_tag_colored'] ) ? (bool) $instance['td_tag_colored'] : false;
        $td_tag_display = isset( $instance['td_tag_display'] ) ? (bool) $instance['td_tag_display'] : false;
        ?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php  esc_html_e( 'Title:', 'jumbo' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
        </p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'td_tags_number' ) ); ?>"><?php  esc_html_e( 'Number of Tags to show:', 'jumbo' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'td_tags_number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'td_tags_number' ) ); ?>" type="text" value="<?php echo esc_attr( $tags_count ); ?>" />
        </p>

        <p>
          <label for="<?php echo esc_attr( $this->get_field_id( 'td_taxonomy' ) ); ?>"><?php  esc_html_e( 'Taxonomy:', 'jumbo' ); ?></label>
          <select id="<?php echo esc_attr( $this->get_field_id( 'td_taxonomy' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'td_taxonomy' ) ); ?>" class="widefat">
            <option value="post_tag"<?php if( $tags_taxonomy == "post_tag" ) echo ' selected="selected"';?>><?php  esc_html_e( 'Tags', 'jumbo' );?></option>
            <option value="category"<?php if( $tags_taxonomy == "category" ) echo ' selected="selected"';?>><?php  esc_html_e( 'Categories', 'jumbo' );?></option>
          </select>
        </p>

        <p>

        <p><input type="checkbox" class="checkbox" id="<?php echo esc_attr( $this->get_field_id('td_tag_colored') ); ?>" name="<?php echo esc_attr( $this->get_field_name('td_tag_colored') ); ?>"<?php checked( $td_tag_colored ); ?> />
        <label for="<?php echo esc_attr( $this->get_field_id('td_tag_colored') ); ?>"><?php  esc_html_e( 'Colored Tags', 'jumbo' ); ?></label>
        </p>


        <p><input type="checkbox" class="checkbox" id="<?php echo esc_attr( $this->get_field_id('td_tag_display') ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'td_tag_display' ) ); ?>"<?php checked( $td_tag_display ); ?> />
        <label for="<?php echo esc_attr( $this->get_field_id( 'td_tag_display' ) ); ?>"><?php  esc_html_e( 'Display tags one per line', 'jumbo' ); ?></label>
        </p>

        <?php
    }

}


/*----------------------------------------------------------------------------------------------------------
  Register Jumbo_Tag_Cloud_Widget widget
-----------------------------------------------------------------------------------------------------------*/

function jumbo_tag_cloud_widgets_init(){
    register_widget( 'Jumbo_Tag_Cloud_Widget' );
}

add_action( 'widgets_init', 'jumbo_tag_cloud_widgets_init' );