<?php
/*----------------------------------------------------------------------------------------------------------
  Jumbo_Vertical_Scroller widget class
-----------------------------------------------------------------------------------------------------------*/
class Jumbo_Vertical_Scroller extends WP_Widget {


/*----------------------------------------------------------------------------------------------------------
  Register widget with WordPress
-----------------------------------------------------------------------------------------------------------*/

function __construct() {
  parent::__construct(
      'jumbo_vertical_scroller', // Base Widget ID
      esc_html__( '[TD] Vertical Scroller', 'jumbo' ), // Widget Name
      array( 'description' => esc_html__( 'A widget that displays posts in a vertical ticker, ordered by: date, most popular, most viewed or in a random order.', 'jumbo' ), ) // Widget Args
      );
}


/*----------------------------------------------------------------------------------------------------------
Front-end display of widget
-----------------------------------------------------------------------------------------------------------*/

public function widget( $args, $instance ) {
extract( $args );

$title            		 = apply_filters( 'widget_title', $instance['title'] );
$orderby               = apply_filters ( 'orderby', isset ( $instance ['orderby'] ) ? $instance ['orderby'] : '' );
$post_type          	 = 'all';
$posts 					       = $instance['posts'];
$categories 			     = $instance['categories'];


echo wp_kses_post( $before_widget );
?>

<?php
$post_types = get_post_types();
unset( $post_types['page'], $post_types['attachment'], $post_types['revision'], $post_types['nav_menu_item'] );
if( $post_type == 'all' ) {
$post_type_array = $post_types;
} else {
$post_type_array = $post_type;
}
?>


<?php // =============================== MAIN BLOCK =============================== ?>

<div class="widget-title">
<h3>
<a href="<?php echo esc_url( get_category_link( $categories ) ); ?>">
	<?php echo esc_html( $title ); ?>
</a>
</h3>

<div class="td-ticker-nav">
<a href="#" id="ticker-previous"></a>
<a href="#" id="ticker-next"></a>
</div>

</div>

<div class="td-wrap-content-sidebar">


<?php
// ----------- SMALL MODULE
// ---------------------------------------------------------------------------
?>
<div class="td-fly-in" >
<ul id="vertical-ticker">

<?php
// ----------- QUERY
// ---------------------------------------------------------------------------
?>

<?php
$metakey = 'post_views_count';
$args = array( 'cat' => $categories, 'orderby' => $orderby, 'meta_key' => $metakey, 'posts_per_page' => $posts );
$numbered_recent_posts = new WP_Query( $args );
?>

<?php if ( $numbered_recent_posts->have_posts() ) : ?>
  <!-- start of the loop -->
<?php while ( $numbered_recent_posts->have_posts() ) : $numbered_recent_posts->the_post(); ?>



<li>
<div class="td-small-module">



<?php
// ----------- thumbnails
// ---------------------------------------------------------------------------
?>

<?php get_template_part( 'post-img' ); ?>

<?php
// ----------- small title
// ---------------------------------------------------------------------------
?>
<div class="td-ticker-post-details"><?php // td-post-details ?>
<div class="td-big-meta">
<div class="block-meta">
<div class="td-time"><?php the_time('F j, Y') ?></div>
</div>
</div>
<h4 class="entry-title">
<a href="<?php echo get_permalink(); ?>" title="<?php echo get_the_title(); ?>">
	<?php echo get_the_title(); ?>
</a>
</h4>

<div class="td-entry-count-views-box">
    <?php jumbo_review_final_score(); ?>
</div>


</div><?php // end of td-post-details ?>


<div class="clearfix"></div>

</div><?php // end of .td-small-module ?>
<div class="clearfix"></div>
</li>
<?php endwhile; ?>
<?php wp_reset_postdata(); ?>
<?php endif; ?>

</ul>
</div><?php // end of .td-fly-in ?>
</div><?php // end of td-wrap-content-sidebar ?>

<?php echo wp_kses_post( $after_widget );

}


/*----------------------------------------------------------------------------------------------------------
  Sanitize widget form values as they are saved
-----------------------------------------------------------------------------------------------------------*/

public function update( $new_instance, $old_instance ) {
$instance = array();
$instance 						   	          = $old_instance;
$instance['title']                 	= strip_tags( $new_instance['title'] );
$instance['orderby']                = strip_tags( $new_instance['orderby'] );
$instance['post_type']             	= 'all';
$instance['posts']                 	= $new_instance['posts'];
$instance['categories']            	= $new_instance['categories'];

return $instance;
}


/*----------------------------------------------------------------------------------------------------------
  Back-end widget form
-----------------------------------------------------------------------------------------------------------*/

public function form( $instance ) {
$defaults = array(
'title'             	=> 'Recent Posts',
'orderby'             => 'date',
'post_type'         	=> 'all',
'posts' 				      => 5,
'categories' 			    => 'all'
);

$orderby = isset ( $instance ['orderby'] ) ? $instance ['orderby'] : '';

$instance = wp_parse_args( (array) $instance, $defaults );



/*----------------------------------------------------------------------------------------------------------
  Widget Options
-----------------------------------------------------------------------------------------------------------*/
?>

<p>
<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php  esc_html_e( 'Title:', 'jumbo' ); ?></label>
<input class="widefat" type="text" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
</p>

<p>
<label for="<?php echo esc_attr( $this->get_field_id( 'categories' ) ); ?>"><?php  esc_html_e( 'Category filter:', 'jumbo' ); ?></label>
<select id="<?php echo esc_attr( $this->get_field_id( 'categories' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'categories' ) ); ?>" class="widefat categories">
<option value='all' <?php if ( 'all' == $instance['categories']) echo 'selected="selected"'; ?>><?php  esc_html_e( 'All Categories', 'jumbo' ); ?></option>
<?php $categories = get_categories( 'hide_empty=0&depth=1&type=post' ); ?>
<?php foreach( $categories as $category ) { ?>
<option value='<?php echo esc_attr( $category->term_id ); ?>' <?php if ( $category->term_id == $instance['categories']) echo 'selected="selected"'; ?>><?php echo esc_attr( $category->cat_name ); ?></option>
<?php } ?>
</select>
</p>

<p>
<label for="<?php echo esc_attr( $this->get_field_id( 'orderby' ) ); ?>"><?php  esc_html_e( 'Sort order:', 'jumbo' ); ?></label>
<select id="<?php echo esc_attr( $this->get_field_id( 'orderby' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'orderby' ) ); ?>" class="widefat">
<option value="date"<?php if( $orderby=="date" ) echo ' selected="selected"';?>><?php  esc_html_e( 'Latest', 'jumbo' );?></option>
<option value="rand"<?php if( $orderby=="rand" ) echo ' selected="selected"';?>><?php  esc_html_e( 'Random', 'jumbo' );?></option>
<option value="name"<?php if( $orderby=="name" ) echo ' selected="selected"';?>><?php  esc_html_e( 'Alphabetical', 'jumbo' );?></option>
<option value="comment_count"<?php if( $orderby=="comment_count" ) echo ' selected="selected"';?>><?php  esc_html_e( 'Most Popular', 'jumbo' );?></option>
<option value="meta_value_num"<?php if( $orderby=="meta_value_num" ) echo ' selected="selected"';?>><?php  esc_html_e( 'Most Viewed', 'jumbo' );?></option>
</select>
</p>

<p>
<label for="<?php echo esc_attr( $this->get_field_id( 'posts' ) ); ?>"><?php  esc_html_e( 'Number of posts to scroll (minimum 4):', 'jumbo' ); ?></label>
<input id="<?php echo esc_attr( $this->get_field_id('posts') ); ?>"  class="widefat" type="text" name="<?php echo esc_attr( $this->get_field_name('posts') ); ?>" value="<?php echo esc_attr( $instance['posts'] ); ?>" />
</p>

<?php
}

}

/*----------------------------------------------------------------------------------------------------------
  Register Jumbo_Vertical_Scroller widget
-----------------------------------------------------------------------------------------------------------*/

function jumbo_vertical_scroller_init(){
register_widget( 'Jumbo_Vertical_Scroller' );
}

add_action( 'widgets_init', 'jumbo_vertical_scroller_init' );